<?php

namespace Netzmacher\Org\Backend;

use Netzmacher\Org\Utility\Typo3VersionUtility;

/* * *************************************************************
 *
 *  The MIT License (MIT)
 *
 *  Copyright (c) 2020 - Dirk Wildt, http://wildt.at.die-netzmacher.de
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 *  THE SOFTWARE.
 *
 * ************************************************************* */

/**
 * @author Dirk Wildt <http://wildt.at.die-netzmacher.de>
 * @package    TYPO3
 * @subpackage  org
 *
 * @version 10.0.0
 * @since 10.0.0
 */
class Extensionmanager
{

	/**
	 * @var array
	 */
	static private $_extConf = '';

	/**
	 * @var array
	 */
	static private $_wasSerialised = false;

	/**
	 * _ExtConfSerialize()
	 * 
	 * @params string $extKey
	 * @access private
	 * @return      void
	 * @version     10.0.0
	 * @since       10.0.0
	 */
	static private function _ExtConfSerialize( $extKey )
	{
		switch( self::$_wasSerialised )
		{
			case(true):
				self::$_extConf = serialize( self::$_extConf );
				break;
			case(false):
				// do nothing
				break;
		}
		switch( TRUE )
		{
			case(Typo3VersionUtility::Get() < 10000000):
				$GLOBALS[ 'TYPO3_CONF_VARS' ][ 'EXT' ][ 'extConf' ][ $extKey ] = self::$_extConf;
				break;
			case(Typo3VersionUtility::Get() >= 10000000):
			default:
				$GLOBALS[ 'TYPO3_CONF_VARS' ][ 'EXTENSIONS' ][ $extKey ] = self::$_extConf;
				break;
		}
		return;
	}

	/**
	 * @access private
	 * @return      void
	 * @version     10.0.0
	 * @since       10.0.0
	 */
	static private function _ExtConfUnserialize()
	{
		if( !is_array( self::$_extConf ) )
		{
			self::$_extConf = unserialize( self::$_extConf );
			self::$_wasSerialised = true;
		}
	}

	/**
	 * _getPropertyByKey()
	 * 
	 * @param string		$key: Key of the extension manager
	 * @return string		$value: corresponding value
	 * @access private
	 * @version 7.0.2
	 * @since 7.0.2
	 */
	static private function _getPropertyByKey( $key )
	{
		$keys = explode( '.', $key );
		switch( count( $keys ) )
		{
			case(1):
				$value = self::$_extConf[ $keys[ 0 ] ];
				break;
			case(2):
				$value = self::$_extConf[ $keys[ 0 ] . '.' ][ $keys[ 1 ] ];
				break;
			case(3):
				$value = self::$_extConf[ $keys[ 0 ] . '.' ][ $keys[ 1 ] . '.' ][ $keys[ 2 ] ];
				break;
			case(4):
				$value = self::$_extConf[ $keys[ 0 ] . '.' ][ $keys[ 1 ] . '.' ][ $keys[ 2 ] . '.' ][ $keys[ 3 ] ];
				break;
			default:
				$prompt = ''
								. '<h1>'
								. '  FATAL ERROR'
								. '</h1>'
								. '<p>'
								. '  Undefined result: count( $keys ) is ' . count( $keys ) . '<br />'
								. '  Error occurs @ ' . __METHOD__ . '#' . __LINE__
								. '</p>'
				;
				die( $prompt );
		}
		return $value;
	}

	/**
	 * _initExtConf
	 * 
	 * @params string $extKey
	 * @access private
	 * @return      void
	 * @version     10.0.0
	 * @since       10.0.0
	 */
	static private function _initExtConf( $extKey )
	{
		switch( TRUE )
		{
			case(Typo3VersionUtility::Get() < 10000000):
				self::$_extConf = $GLOBALS[ 'TYPO3_CONF_VARS' ][ 'EXT' ][ 'extConf' ][ $extKey ];
				break;
			case(Typo3VersionUtility::Get() >= 10000000):
			default:
				self::$_extConf = $GLOBALS[ 'TYPO3_CONF_VARS' ][ 'EXTENSIONS' ][ $extKey ];
				break;
		}
	}

	/**
	 * _setPropertyByKey()
	 * 
	 * @param string		$key: Key of the extension manager
	 * @param string		$value
	 * @return void
	 * @access private
	 * @version 7.0.2
	 * @since 7.0.2
	 */
	static private function _setPropertyByKey( $key, $value )
	{
		$keys = explode( '.', $key );
		switch( count( $keys ) )
		{
			case(1):
				self::$_extConf[ $keys[ 0 ] ] = $value;
				break;
			case(2):
				self::$_extConf[ $keys[ 0 ] . '.' ][ $keys[ 1 ] ] = $value;
				break;
			case(3):
				self::$_extConf[ $keys[ 0 ] . '.' ][ $keys[ 1 ] . '.' ][ $keys[ 2 ] ] = $value;
				break;
			case(4):
				self::$_extConf[ $keys[ 0 ] . '.' ][ $keys[ 1 ] . '.' ][ $keys[ 2 ] . '.' ][ $keys[ 3 ] ] = $value;
				break;
			default:
				$prompt = ''
								. '<h1>'
								. '  FATAL ERROR'
								. '</h1>'
								. '<p>'
								. '  Undefined result: count( $keys ) is ' . count( $keys ) . '<br />'
								. '  Error occurs @ ' . __METHOD__ . '#' . __LINE__
								. '</p>'
				;
				die( $prompt );
		}
	}

	/**
	 * getProperty()
	 * 
	 * @param string		$key: Key of the extension manager
	 * @param string		$extKey: extension key
	 * @return string		$value: corresponding value
	 * @access private
	 * @version 10.0.0
	 * @since 10.0.0
	 */
	static public function getProperty( $key, $extKey = 'org' )
	{
		self::_initExtConf( $extKey );
		self::_ExtConfUnserialize();
//		var_dump( __METHOD__, __LINE__, self::$_extConf );
//		die();
		$value = self::_getPropertyByKey( $key, $extKey );
		self::_ExtConfSerialize( $extKey );

		return $value;
	}

	/**
	 * setProperty()
	 * 
	 * @param string		$key: Key of the extension manager
	 * @param string		$value: 
	 * @param string		$extKey: extension key
	 * @return void
	 * @access private
	 * @version 10.0.0
	 * @since 10.0.0
	 */
	static public function setProperty( $key, $value, $extKey = 'org' )
	{
		self::_initExtConf( $extKey );
		self::_ExtConfUnserialize();
		self::_setPropertyByKey( $key, $value );
		self::_ExtConfSerialize( $extKey );
	}

}
