<?php

namespace Netzmacher\Org\TCA;

use Netzmacher\Org\Utility\Typo3VersionUtility;

/* * *************************************************************
 *  Copyright notice
 *
 *  (c) 2018-2020 - Dirk Wildt <http://wildt.at.die-netzmacher.de/>
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 * ************************************************************* */

/**
 * @author      Dirk Wildt <http://wildt.at.die-netzmacher.de>
 * @package     TYPO3
 * @subpackage  org
 * @version 10.0.2
 * @since 8.10.0
 */
class Columns
{

	/**
	 * @return array
	 * @access public
	 * @version 10.0.2
	 * @since 10.0.2
	 */
	static public function Author()
	{
		return array(
				'exclude' => 1,
				'label' => 'LLL:EXT:org/Resources/Private/Language/tx_org.xml:label.author',
				'config' => array(
						'type' => 'input',
						'size' => '20',
						'eval' => 'trim'
				),
		);
	}

	/**
	 * @return array
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static public function Bodytext()
	{
		return array(
				'exclude' => 0,
				'l10n_mode' => 'prefixLangTitle',
				'label' => 'LLL:EXT:org/Resources/Private/Language/tx_org.xml:label.bodytext',
				'config' => \Netzmacher\Org\TCA\Columns\Config::RTE(),
		);
	}

	/**
	 * @return array
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static public function FeCrUserId()
	{
		return array(
				'exclude' => 1,
				'label' => 'LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.fe_cruser_id',
				'config' => Array(
						'type' => 'group',
						'internal_type' => 'db',
						'allowed' => 'fe_users',
						'size' => '1',
						'maxitems' => '1',
						'minitems' => '0',
						'default' => 0,
				)
		);
	}

	/**
	 * @access public
	 * @param				array	$columns
	 * @param				boolean $fal
	 * @return      string
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static public function Icon( $columns )
	{
		$iconColumns = SELF::_IconFAL();

		$columns = ( array ) $columns + ( array ) $iconColumns;
		return $columns;
	}

	/**
	 * @access public
	 * @param				array	$columns
	 * @param				boolean $fal
	 * @return      string
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static public function IconMedium( $columns )
	{
		$iconColumns = SELF::_IconMediumFAL();

		$columns = ( array ) $columns + ( array ) $iconColumns;
		return $columns;
	}

	/**
	 * @access public
	 * @param				array		$columns
	 * @param				string	$case: small || medieum || big
	 * @param				boolean $fal
	 * @return      array		$columns
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static public function ImageColumns( $columns, $image_1stforlistonly = false )
	{
		$imageColumns = SELF::_ImageColumnsFAL( $image_1stforlistonly );

		$columns = ( array ) $columns + ( array ) $imageColumns;
		return $columns;
	}
	/**
	 * @return array
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static public function L10nDiffsource()
	{
		return array(
				'config' => array(
						'type' => 'passthrough'
				),
		);
	}

	/**
	 * @return array
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static public function L10nParent()
	{
		return array(
				'displayCond' => 'FIELD:sys_language_uid:>:0',
				'exclude' => 1,
				'label' => 'LLL:EXT:lang/locallang_general.php:LGL.l18n_parent',
				'config' => array(
						'type' => 'select',
						// #t1668, 171206, dwildt, 1+
						'renderType' => 'selectSingle',
						'items' => array(
								array( '', 0 ),
						),
						'foreign_table' => 'tx_org_news',
						'foreign_table_where' => 'AND tx_org_news.uid=###REC_FIELD_l10n_parent### AND tx_org_news.sys_language_uid IN (-1,0)',
				),
		);
	}
	/**
	 * @return array
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static public function MarginalShort()
	{
		return array(
				'exclude' => 1,
				'l10n_mode' => 'prefixLangTitle',
				'label' => 'LLL:EXT:org/Resources/Private/Language/tx_org.xml:label.marginal_short',
				'config' => array(
						'type' => 'text',
						'cols' => '50',
						'rows' => '10',
				),
		);
	}

	/**
	 * @return array
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static public function MarginalSubtitle()
	{
		return array(
				'exclude' => 1,
				'l10n_mode' => 'prefixLangTitle',
				'label' => 'LLL:EXT:org/Resources/Private/Language/tx_org.xml:label.marginal_subtitle',
				'config' => array(
						'type' => 'input',
						'size' => '30',
						'eval' => 'trim'
				),
		);
	}

	/**
	 * @return array
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static public function MarginalTitle()
	{
		return array(
				'exclude' => 1,
				'l10n_mode' => 'prefixLangTitle',
				'label' => 'LLL:EXT:org/Resources/Private/Language/tx_org.xml:label.marginal_title',
				'config' => array(
						'type' => 'input',
						'size' => '30',
						'eval' => 'trim'
				),
		);
	}

	/**
	 * @access public
	 * @param				array		$columns
	 * @param				string	$table
	 * @return      array		$columns
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static public function MediaColumns( $columns, $table )
	{
		$mediaColumns = SELF::_MediaColumnsFAL( $table );

		$columns = ( array ) $columns + ( array ) $mediaColumns;
		return $columns;
	}

	/**
	 * @return		string
	 * @access		public
	 * @version		8.11.0
	 * @since			8.11.0
	 */
	static public function Page()
	{
		return array(
				'exclude' => 0,
//      'l10n_mode' => 'exclude',
				'label' => 'LLL:EXT:org/Resources/Private/Language/locallang_db.xml:page',
				'config' => array(
						'type' => 'group',
						'internal_type' => 'db',
						'allowed' => 'pages',
						'size' => '1',
						'maxitems' => '1',
						'minitems' => '1',
						'wizards' => array(
								'_PADDING' => 2,
								'_VERTICAL' => 1,
						),
						'default' => 0,
				),
		);
	}

	/**
	 * @param		string $table_main
	 * @param		string $table_foreign
	 * @return array
	 * @access public
	 * @version 8.11.0
	 * @since 8.11.0
	 */
	static public function SelectCheckBox( $table_main, $table_foreign )
	{
		return array(
				'exclude' => 1,
				'label' => 'LLL:EXT:org/Resources/Private/Language/tx_org.xml:' . $table_foreign,
				'config' => \Netzmacher\Org\TCA\Columns\Config::SelectCheckBox(
								$table_main
								, $table_foreign
								, ''
								. 'AND ' . $table_foreign . '.' . \Netzmacher\Org\Utility\ExtensionManager\Simplifyer::getPidConfigration() . ' '
								. 'AND ' . $table_foreign . '.deleted = 0 '
								. 'AND ' . $table_foreign . '.hidden = 0 '
								. 'ORDER BY ' . $table_foreign . '.title'
				),
		);
	}

	/**
	 * @param string $MMlocal table_local
	 * @param string $MMforeign table_foreign
	 * @param string $OrderBy Orderby field
	 * @param string $MMopposite Opposite field in case of an opposite relation.
	 * @return array
	 * @access public
	 * @version 8.11.0
	 * @since 8.11.0
	 */
	static public function SelectMultipleSideBySide( $MMlocal, $MMforeign, $OrderBy = NULL, $MMopposite = NULL )
	{
		$where = SELF::_selectWhere( $MMlocal, $MMforeign, $OrderBy, $MMopposite );
		return array(
				'exclude' => 1,
				'label' => 'LLL:EXT:org/Resources/Private/Language/tx_org.xml:' . $MMforeign,
				'config' => \Netzmacher\Org\TCA\Columns\Config::SelectMultipleSideBySide(
								$MMlocal
								, $MMforeign
								, $MMopposite
								, $where
								, 9999
				),
		);
	}

	/**
	 * @param string $MMlocal table_local
	 * @param string $MMforeign table_foreign
	 * @param string $OrderBy Orderby field
	 * @param string $MMopposite Opposite field in case of an opposite relation.
	 * @return array
	 * @access public
	 * @version 8.11.0
	 * @since 8.11.0
	 */
	static public function SelectMultipleSideBySideOneItem( $MMlocal, $MMforeign, $OrderBy = NULL, $MMopposite = NULL )
	{
		$where = SELF::_selectWhere( $MMlocal, $MMforeign, $OrderBy, $MMopposite );
		return array(
				'exclude' => 1,
				'label' => 'LLL:EXT:org/Resources/Private/Language/tx_org.xml:' . $MMforeign,
				'config' => \Netzmacher\Org\TCA\Columns\Config::SelectMultipleSideBySide(
								$MMlocal
								, $MMforeign
								, $MMopposite
								, $where
								, 1
				),
		);
	}

	/**
	 * @param		string $table
	 * @return array
	 * @access public
	 * @version 8.11.0
	 * @since 8.11.0
	 */
	static public function SelectSingle( $table, $orderby = NULL, $size = 1, $maxitems = 1 )
	{
		return array(
				'exclude' => 1,
				'label' => 'LLL:EXT:org/Resources/Private/Language/tx_org.xml:' . $table,
				'config' => array(
						'type' => 'select',
						'renderType' => 'selectSingle',
						'size' => $size,
						'minitems' => 0,
						'maxitems' => $maxitems,
						'items' => array(
								'0' => array( '', 0 ),
						),
						'foreign_table' => $table,
						'foreign_table_where' => ''
						. 'AND '
						. $table . '.'
						. \Netzmacher\Org\Utility\ExtensionManager\Simplifyer::getPidConfigration()
						. ' ORDER BY ' . SELF::_selectOrderBy( $table, $orderby )
				),
		);
	}

	/**
	 * @param		string $table_main
	 * @param		string $table_foreign
	 * @return array
	 * @access public
	 * @version 8.11.0
	 * @since 8.11.0
	 */
	static public function SelectSingleBox( $table_main, $table_foreign )
	{
		return array(
				'exclude' => 1,
				'label' => 'LLL:EXT:org/Resources/Private/Language/tx_org.xml:' . $table_foreign,
				'config' => \Netzmacher\Org\TCA\Columns\Config::SelectSingleBox(
								$table_main
								, $table_foreign
								, ''
								. 'AND ' . $table_foreign . '.' . \Netzmacher\Org\Utility\ExtensionManager\Simplifyer::getPidConfigration() . ' '
								. 'AND ' . $table_foreign . '.deleted = 0 '
								. 'AND ' . $table_foreign . '.hidden = 0 '
								. 'ORDER BY ' . $table_foreign . '.title'
				),
		);
	}

	/**
	 * @param		string $table_main
	 * @param		string $table_foreign
	 * @return array
	 * @access public
	 * @version 8.11.0
	 * @since 8.11.0
	 */
	static public function SelectTree( $table_main, $table_foreign )
	{
		return array(
				'exclude' => 1,
				'label' => 'LLL:EXT:org/Resources/Private/Language/tx_org.xml:' . $table_foreign,
				'config' => \Netzmacher\Org\TCA\Columns\Config::SelectTree(
								$table_main
								, $table_foreign
								, ''
								. 'AND ' . $table_foreign . '.' . \Netzmacher\Org\Utility\ExtensionManager\Simplifyer::getPidConfigration() . ' '
								. 'AND ' . $table_foreign . '.deleted = 0 '
								. 'AND ' . $table_foreign . '.hidden = 0 '
								. 'ORDER BY ' . $table_foreign . '.title'
				),
		);
	}

	/**
	 * @return array
	 * @access public
	 * @version 8.11.0
	 * @since 8.11.0
	 */
	static public function SeoDescription()
	{
		return array(
				'exclude' => 1,
				'label' => 'LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.seo_description',
				'l10n_mode' => 'prefixLangTitle',
				'config' => array(
						'type' => 'text',
						'cols' => '50',
						'rows' => '10',
				),
		);
	}

	/**
	 * @return array
	 * @access public
	 * @version 8.11.0
	 * @since 8.11.0
	 */
	static public function SeoKeywords()
	{
		return array(
				'exclude' => 1,
				'label' => 'LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.seo_keywords',
				'l10n_mode' => 'prefixLangTitle',
				'config' => array(
						'type' => 'input',
						'size' => '80',
						'eval' => 'trim'
				),
		);
	}

	/**
	 * @return array
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static public function Subtitle()
	{
		return array(
				'exclude' => 1,
				'l10n_mode' => 'prefixLangTitle',
				'label' => 'LLL:EXT:org/Resources/Private/Language/tx_org.xml:label.subtitle',
				'config' => array(
						'type' => 'input',
						'size' => '30',
						'eval' => 'trim'
				),
		);
	}

	/**
	 * @return array
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static public function SysLanguageUid()
	{
		return array(
				'exclude' => 1,
				'label' => 'LLL:EXT:lang/locallang_general.xlf:LGL.language',
				'config' => array(
						'type' => 'select',
						'renderType' => 'selectSingle',
						'special' => 'languages',
						'items' => array(
								array(
										'LLL:EXT:lang/locallang_general.xlf:LGL.allLanguages',
										-1,
										'flags-multiple'
								),
						),
						'default' => 0,
				)
		);
	}

	/**
	 * @return array
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static public function TeaserShort()
	{
		return array(
				'exclude' => 1,
				'l10n_mode' => 'prefixLangTitle',
				'label' => 'LLL:EXT:org/Resources/Private/Language/tx_org.xml:label.teaser_short',
				'config' => array(
						'type' => 'text',
						'cols' => '50',
						'rows' => '10',
				),
		);
	}

	/**
	 * @return array
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static public function TeaserShortForSingleview()
	{
		return array(
				'exclude' => 1,
				'l10n_mode' => 'prefixLangTitle',
				'label' => 'LLL:EXT:org/Resources/Private/Language/tx_org.xml:label.teaser_short_for_singleview',
				'config' => array(
						'type' => 'check',
						'default' => '0',
				),
		);
	}

	/**
	 * @return array
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static public function TeaserSubtitle()
	{
		return array(
				'exclude' => 1,
				'l10n_mode' => 'prefixLangTitle',
				'label' => 'LLL:EXT:org/Resources/Private/Language/tx_org.xml:label.teaser_subtitle',
				'config' => array(
						'type' => 'input',
						'size' => '30',
						'eval' => 'trim'
				),
		);
	}

	/**
	 * @return array
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static public function TeaserTitle()
	{
		return array(
				'exclude' => 1,
				'l10n_mode' => 'prefixLangTitle',
				'label' => 'LLL:EXT:org/Resources/Private/Language/tx_org.xml:label.teaser_title',
				'config' => array(
						'type' => 'input',
						'size' => '30',
						'eval' => 'trim'
				),
		);
	}

	/**
	 * @return array
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static public function Thumbnail()
	{
		return SELF::_ThumbnailFAL();
	}

	/**
	 * @return array
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static public function Title()
	{
		return array(
				'exclude' => 0,
				'l10n_mode' => 'prefixLangTitle',
				'label' => 'LLL:EXT:org/Resources/Private/Language/tx_org.xml:label.title',
				'config' => array(
						'type' => 'input',
						'size' => '30',
						'eval' => 'trim,required'
				),
		);
	}

	/**
	 * @return array
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static public function Translation()
	{
		return array(
				'exclude' => 0,
				'l10n_mode' => 'prefixLangTitle',
				'label' => 'LLL:EXT:org/Resources/Private/Language/tx_org.xml:label.translation',
				'config' => array(
						'type' => 'input',
						'size' => '30',
						'eval' => 'trim'
				),
		);
	}

	/**
	 * @param		string	$table
	 * @return	array
	 * @access	public
	 * @version	8.11.0
	 * @since		8.11.0
	 */
	static public function Type( $table )
	{
		$return = array(
				'exclude' => 1,
				'l10n_mode' => 'exclude',
				'label' => 'LLL:EXT:org/Resources/Private/Language/locallang_db.xml:type',
				'config' => array(
						'type' => 'select',
						// #t1668, 171206, dwildt, 1+
						'renderType' => 'selectSingle',
						'items' => array(
								'record' => array(
										'0' => 'LLL:EXT:org/Resources/Private/Language/locallang_db.xml:type_record',
										'1' => 'record',
										'2' => 'EXT:org/Resources/Public/Images/Icons/ExtIcon/' . $table . '.' . \Netzmacher\Org\TCA\Columns\Type\Items::Ext(),
								),
								'page' => array(
										'0' => 'LLL:EXT:org/Resources/Private/Language/locallang_db.xml:type_page',
										'1' => 'page',
										'2' => 'EXT:org/Resources/Public/Images/Icons/ExtIcon/page.' . \Netzmacher\Org\TCA\Columns\Type\Items::Ext(),
								),
								'url' => array(
										'0' => 'LLL:EXT:org/Resources/Private/Language/locallang_db.xml:type_url',
										'1' => 'url',
										'2' => 'EXT:org/Resources/Public/Images/Icons/ExtIcon/url.' . \Netzmacher\Org\TCA\Columns\Type\Items::Ext(),
								),
								'notype' => array(
										'0' => 'LLL:EXT:org/Resources/Private/Language/locallang_db.xml:type_notype',
										'1' => 'notype',
										'2' => 'EXT:org/Resources/Public/Images/Icons/ExtIcon/notype.' . \Netzmacher\Org\TCA\Columns\Type\Items::Ext(),
								),
						),
						'default' => 'record',
				),
		);

		switch( $table )
		{
			case('tx_org_cal'):
				$return[ 'config' ][ 'items' ][ 'tx_org_event' ] = [
						'0' => 'LLL:EXT:org/Resources/Private/Language/tx_org.xml:tx_org_event',
						'1' => 'tx_org_event',
						'2' => 'EXT:org/Resources/Public/Images/Icons/ExtIcon/tx_org_event.' . \Netzmacher\Org\TCA\Columns\Type\Items::Ext(),
				];
				$return[ 'config' ][ 'items' ][ 'tx_org_seminar' ] = [
						'0' => 'LLL:EXT:org/Resources/Private/Language/tx_org.xml:tx_org_seminar',
						'1' => 'tx_org_seminar',
						'2' => 'EXT:org/Resources/Public/Images/Icons/ExtIcon/tx_org_seminar.' . \Netzmacher\Org\TCA\Columns\Type\Items::Ext(),
				];
				break;
			default:
				// do nothing
				break;
		}

		return $return;
	}

	/**
	 * @return string
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static public function URL()
	{
		return array(
				'exclude' => 0,
//      'l10n_mode' => 'exclude',
				'label' => 'LLL:EXT:org/Resources/Private/Language/locallang_db.xml:url',
				'config' => \Netzmacher\Org\TCA\Columns\Wizards::Url(),
		);
	}

	/**
	 * @return string
	 * @access public
	 * @version 8.12.0
	 * @since 8.12.0
	 */
	static public function URLticket()
	{
		return array(
				'exclude' => 0,
//      'l10n_mode' => 'exclude',
				'label' => 'LLL:EXT:org/Resources/Private/Language/locallang_db.xml:urlticket',
				'config' => \Netzmacher\Org\TCA\Columns\Wizards::Url(),
		);
	}

	/**
	 * UidParent() : Renders a TCA selecttree
	 *
	 * @param string $foreign foreign_table
	 * @param string $where SQL-where-statement for table_foreign
	 * @param integer $size Size of the visible parte of the tree in lines
	 * @param boolean $expandAll expand the tree by default 
	 * @param string $parentField foreign_table
	 * 
	 * @return void
	 * @access public
	 * @version 8.10.0
	 * @since 8.10.0
	 */
	static function UidParent( $foreign_table, $where = NULL, $size = 20, $expandAll = false, $parentField = 'uid_parent' )
	{
		$return = array(
				'exclude' => 1,
				'label' => 'LLL:EXT:org/Resources/Private/Language/tx_org.xml:label.uid_parent',
				'config' => array(
						'type' => 'select',
						'renderMode' => 'tree', // TYPO3 6.x
						'renderType' => 'selectTree', // TYPO3 7.6
						'foreign_table' => $foreign_table,
						'size' => $size,
						'treeConfig' => array(
								'parentField' => $parentField,
								'appearance' => array(
										'expandAll' => $expandAll,
										'showHeader' => true,
								),
						),
						'default' => 0,
				),
		);

		if( $where )
		{
			$return[ 'config' ][ 'foreign_table_where' ] = $where;
		}

		return $return;
	}

	/**
	 * @access private
	 * @return      array
	 * @version     8.14.4
	 * @since       7.0.2
	 */
	static private function _IconFAL()
	{
		$image = array(
				'icons' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'image' ],
				'icon_offset_x' => array(
						'exclude' => 1,
						'label' => 'LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.icon_offset_x',
						'config' => array(
								'type' => 'input',
								'size' => '3',
								'max' => '3',
								'eval' => 'int',
								'default' => '0',
						),
				),
				'icon_offset_y' => array(
						'exclude' => 1,
						'label' => 'LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.icon_offset_y',
						'config' => array(
								'type' => 'input',
								'size' => '3',
								'max' => '3',
								'eval' => 'int',
								'default' => '0',
						),
				),
		);
		// #i0324, 180625, dwildt; 1+
		$image[ 'icons' ][ 'exclude' ] = 1;
		return $image;
	}

	/**
	 * @access private
	 * @param				boolean $fal
	 * @return      string
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static private function _IconMediumFAL()
	{
		$TYPO3_version = Typo3VersionUtility::Get();

		switch( TRUE )
		{
			case ( $TYPO3_version < 8007000 ):
				return SELF::_IconMediumFALCss();
			case ( $TYPO3_version >= 8007000 ):
			default:
				return SELF::_IconMediumFALFluid();
		}
	}

	/**
	 * @param				string	$case: small || medieum || big
	 * @param				boolean $fal
	 * @return      string
	 * @access private
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static private function _IconMediumFALCss()
	{
		return array(
				'image' => array(
						'label' => 'LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.icons',
						'config' => \TYPO3\CMS\Core\Utility\ExtensionManagementUtility::getFileFieldTCAConfig( 'image', array(
								'appearance' => array(
										'createNewRelationLinkTitle' => 'LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:images.addFileReference'
								),
								// custom configuration for displaying fields in the overlay/reference table
								// to use the imageoverlayPalette instead of the basicoverlayPalette
								'foreign_types' => array(
										'0' => array(
												'showitem' => '
							--palette--;LLL:EXT:lang/locallang_tca.xlf:sys_file_reference.imageoverlayPalette;imageoverlayPalette,
							--palette--;;filePalette'
										),
										\TYPO3\CMS\Core\Resource\File::FILETYPE_TEXT => array(
												'showitem' => '
							--palette--;LLL:EXT:lang/locallang_tca.xlf:sys_file_reference.imageoverlayPalette;imageoverlayPalette,
							--palette--;;filePalette'
										),
										\TYPO3\CMS\Core\Resource\File::FILETYPE_IMAGE => array(
												'showitem' => '
							--palette--;LLL:EXT:lang/locallang_tca.xlf:sys_file_reference.imageoverlayPalette;imageoverlayPalette,
							--palette--;;filePalette'
										),
										\TYPO3\CMS\Core\Resource\File::FILETYPE_AUDIO => array(
												'showitem' => '
							--palette--;LLL:EXT:lang/locallang_tca.xlf:sys_file_reference.audioOverlayPalette;audioOverlayPalette,
							--palette--;;filePalette'
										),
										\TYPO3\CMS\Core\Resource\File::FILETYPE_VIDEO => array(
												'showitem' => '
							--palette--;LLL:EXT:lang/locallang_tca.xlf:sys_file_reference.videoOverlayPalette;videoOverlayPalette,
							--palette--;;filePalette'
										),
										\TYPO3\CMS\Core\Resource\File::FILETYPE_APPLICATION => array(
												'showitem' => '
							--palette--;LLL:EXT:lang/locallang_tca.xlf:sys_file_reference.imageoverlayPalette;imageoverlayPalette,
							--palette--;;filePalette'
										)
								)
										,
										)
										, $GLOBALS[ 'TYPO3_CONF_VARS' ][ 'GFX' ][ 'imagefile_ext' ] )
				),
				'imagewidth' => array(
						'exclude' => 1,
						'label' => 'LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:imagewidth',
						'config' => array(
								'type' => 'input',
								'size' => '4',
								'max' => '4',
								'eval' => 'int',
								'range' => array(
										'upper' => 1999,
										'lower' => 0,
								),
								'default' => 0
						)
				),
				'imageheight' => array(
						'exclude' => 1,
						'label' => 'LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:imageheight',
						'config' => array(
								'type' => 'input',
								'size' => '4',
								'max' => '4',
								'eval' => 'int',
								'range' => array(
										'upper' => 1999,
										'lower' => 0,
								),
								'default' => 0
						)
				),
				'image_compression' => array(
						'exclude' => true,
						'label' => 'LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:image_compression',
						'config' => array(
								'type' => 'select',
								'renderType' => 'selectSingle',
								'items' => array(
										array(
												'LLL:EXT:lang/locallang_general.xlf:LGL.default_value',
												0
										),
										array(
												'LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:image_compression.I.1',
												1
										),
										array(
												'GIF/256',
												10
										),
										array(
												'GIF/128',
												11
										),
										array(
												'GIF/64',
												12
										),
										array(
												'GIF/32',
												13
										),
										array(
												'GIF/16',
												14
										),
										array(
												'GIF/8',
												15
										),
										array(
												'PNG',
												39
										),
										array(
												'PNG/256',
												30
										),
										array(
												'PNG/128',
												31
										),
										array(
												'PNG/64',
												32
										),
										array(
												'PNG/32',
												33
										),
										array(
												'PNG/16',
												34
										),
										array(
												'PNG/8',
												35
										),
										array(
												'LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:image_compression.I.15',
												21
										),
										array(
												'LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:image_compression.I.16',
												22
										),
										array(
												'LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:image_compression.I.17',
												24
										),
										array(
												'LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:image_compression.I.18',
												26
										),
										array(
												'LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:image_compression.I.19',
												28
										)
								)
						)
				),
				'image_effects' => array(
						'exclude' => true,
						'label' => 'LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:image_effects',
						'config' => array(
								'type' => 'select',
								'renderType' => 'selectSingle',
								'items' => array(
										array(
												'LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:image_effects.I.0',
												0
										),
										array(
												'LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:image_effects.I.1',
												1
										),
										array(
												'LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:image_effects.I.2',
												2
										),
										array(
												'LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:image_effects.I.3',
												3
										),
										array(
												'LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:image_effects.I.4',
												10
										),
										array(
												'LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:image_effects.I.5',
												11
										),
										array(
												'LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:image_effects.I.6',
												20
										),
										array(
												'LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:image_effects.I.7',
												23
										),
										array(
												'LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:image_effects.I.8',
												25
										),
										array(
												'LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:image_effects.I.9',
												26
										)
								)
						)
				),
		);
	}

	/**
	 * @return      string
	 * @access private
	 * @version     10.0.0
	 * @since       7.0.2
	 */
	static private function _IconMediumFALFluid()
	{
		$image = NULL;
		$image = self::_setIfFieldExist( $image, 'image' );
		$image = self::_setIfFieldExist( $image, 'imageheight' );
		$image = self::_setIfFieldExist( $image, 'imagewidth' );
		$image = self::_setIfFieldExist( $image, 'image_compression' );
		$image = self::_setIfFieldExist( $image, 'image_effects' );
		
		return $image;
	}

	/**
	 * @access private
	 * @param				string	$case: small || medieum || big
	 * @param				boolean $fal
	 * @return      string
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static private function _ImageColumnsFAL( $image_1stforlistonly = false )
	{
		$TYPO3_version = Typo3VersionUtility::Get();

		switch( TRUE )
		{
			case ( $TYPO3_version < 8007000 ):
				return SELF::_ImageColumnsFALCss( $image_1stforlistonly );
			case ( $TYPO3_version >= 8007000 ):
			default:
				return SELF::_ImageColumnsFALFluid( $image_1stforlistonly );
		}
	}

	/**
	 * @param				string	$case: small || medieum || big
	 * @param				boolean $fal
	 * @return      string
	 * @access private
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static private function _ImageColumnsFALCss( $image_1stforlistonly = false )
	{
		$image = NULL;
		$image = self::_setIfFieldExist( $image, 'image' );
		$image = self::_setIfFieldExist( $image, 'imageborder' );
		$image = self::_setIfFieldExist( $image, 'imagecols' );
		$image = self::_setIfFieldExist( $image, 'imageheight' );
		$image = self::_setIfFieldExist( $image, 'imageorient' );
		$image = self::_setIfFieldExist( $image, 'imagewidth' );
		$image = self::_setIfFieldExist( $image, 'image_compression' );
		$image = self::_setIfFieldExist( $image, 'image_effects' );
		$image = self::_setIfFieldExist( $image, 'image_noRows' );
		$image = self::_setIfFieldExist( $image, 'layout' );
		$image = self::_setIfFieldExist( $image, 'section_frame' );
		$image = self::_setIfFieldExist( $image, 'spaceAfter' );
		$image = self::_setIfFieldExist( $image, 'spaceBefore' );

		unset( $image[ 'imageheight' ][ 'config' ][ 'eval' ] );
		unset( $image[ 'imagewidth' ][ 'config' ][ 'eval' ] );
		unset( $image[ 'imageheight' ][ 'config' ][ 'range' ] );
		unset( $image[ 'imagewidth' ][ 'config' ][ 'range' ] );
		$image[ 'imageheight' ][ 'config' ][ 'max' ] = 5;
		$image[ 'imageheight' ][ 'config' ][ 'size' ] = 5;
		$image[ 'imagewidth' ][ 'config' ][ 'max' ] = 5;
		$image[ 'imagewidth' ][ 'config' ][ 'size' ] = 5;

		if( $image_1stforlistonly )
		{
			$image = $image + array(
					'image_1stforlistonly' => array(
							'exclude' => 1,
							'l10n_mode' => 'exclude',
							'label' => 'LLL:EXT:org/Resources/Private/Language/tx_org.xml:tca_phrase.image_1stforlistonly',
							'config' => array(
									'type' => 'check'
							),
					),
			);
		}

		return $image;
	}

	/**
	 * @param				string	$case: small || medieum || big
	 * @param				boolean $fal
	 * @return      string
	 * @access private
	 * @version     10.0.0
	 * @since       10.0.0
	 */
	static private function _setIfFieldExist( $conf, $field, $table = 'tt_content' )
	{
		if( !isset( $GLOBALS[ 'TCA' ][ $table ][ 'columns' ][ $field ] ) )
		{
			return $conf;
		}

		$conf[ $field ] = $GLOBALS[ 'TCA' ][ $table ][ 'columns' ][ $field ];

		return $conf;
	}

	/**
	 * @param				string	$case: small || medieum || big
	 * @param				boolean $fal
	 * @return      string
	 * @access private
	 * @version     10.0.0
	 * @since       7.0.2
	 */
	static private function _ImageColumnsFALFluid( $image_1stforlistonly = false )
	{
		$image = NULL;
		$image = self::_setIfFieldExist( $image, 'frame_class' );
		$image = self::_setIfFieldExist( $image, 'image' );
		$image = self::_setIfFieldExist( $image, 'imageborder' );
		$image = self::_setIfFieldExist( $image, 'imagecols' );
		$image = self::_setIfFieldExist( $image, 'imageheight' );
		$image = self::_setIfFieldExist( $image, 'imageorient' );
		$image = self::_setIfFieldExist( $image, 'imagewidth' );
		$image = self::_setIfFieldExist( $image, 'image_zoom' );
		$image = self::_setIfFieldExist( $image, 'layout' );
		$image = self::_setIfFieldExist( $image, 'space_after_class' );
		$image = self::_setIfFieldExist( $image, 'space_before_class' );

		unset( $image[ 'imageheight' ][ 'config' ][ 'eval' ] );
		unset( $image[ 'imagewidth' ][ 'config' ][ 'eval' ] );
		unset( $image[ 'imageheight' ][ 'config' ][ 'range' ] );
		unset( $image[ 'imagewidth' ][ 'config' ][ 'range' ] );
		$image[ 'imageheight' ][ 'config' ][ 'max' ] = 5;
		$image[ 'imageheight' ][ 'config' ][ 'size' ] = 5;
		$image[ 'imagewidth' ][ 'config' ][ 'max' ] = 5;
		$image[ 'imagewidth' ][ 'config' ][ 'size' ] = 5;

		if( $image_1stforlistonly )
		{
			$image = $image + array(
					'image_1stforlistonly' => array(
							'exclude' => 1,
							'l10n_mode' => 'exclude',
							'label' => 'LLL:EXT:org/Resources/Private/Language/tx_org.xml:tca_phrase.image_1stforlistonly',
							'config' => array(
									'type' => 'check'
							),
					),
			);
		}

		return $image;
	}

	/**
	 * @access private
	 * @param				string	$table
	 * @return      string
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static private function _MediaColumnsFAL( $table )
	{
		$tcaColumnsMediaFAL = array(
				// See: typo3/sysext/fluid_styled_content/Configuration/TCA/Overrides/tt_content.php
				'documents' => array(
						'label' => 'LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.documents',
						'config' => \TYPO3\CMS\Core\Utility\ExtensionManagementUtility::getFileFieldTCAConfig( 'documents', array(
								'appearance' => array(
										'createNewRelationLinkTitle' => 'LLL:EXT:fluid_styled_content/Resources/Private/Language/Database.xlf:tt_content.asset_references.addFileReference'
								)
								, 'foreign_types' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'image' ][ 'config' ][ 'foreign_types' ]
										)
										, $GLOBALS[ 'TYPO3_CONF_VARS' ][ 'GFX' ][ 'imagefile_ext' ] . ',doc,docx,ods,odt,sxw,xls,xlsx'
						),
				),
				'documentslayout' => array(
						'exclude' => 1,
						'l10n_mode' => 'exclude',
						'label' => 'LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.documentslayout',
						'config' => array(
								'type' => 'select',
								// #t1668, 171206, dwildt, 1+
								'renderType' => 'selectSingle',
								'size' => 1,
								'maxitems' => 1,
								'items' => array(
										array( 'LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.documentslayout.0', 0 ),
										array( 'LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.documentslayout.1', 1 ),
										array( 'LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.documentslayout.2', 2 ),
								),
						),
				),
				'documentssize' => array(
						'exclude' => 1,
						//'l10n_mode' => 'exclude',
						'label' => 'LLL:EXT:org/Resources/Private/Language/6x/cms/locallang_ttc.xlf:filelink_size',
						'config' => array(
								'type' => 'check',
								'items' => array(
										'1' => array(
												'0' => 'LLL:EXT:lang/locallang_core.xml:labels.enabled',
										),
								),
								'default' => '1'
						),
				),
				'documents_from_path' => array(
						'exclude' => 1,
						//'l10n_mode' => 'exclude',
						'label' => 'LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.documents_from_path',
						'config' => array(
								'type' => 'input',
								'size' => '50',
								'max' => '80',
								'eval' => 'trim',
						),
				),
		);

		switch( $table )
		{
			case('tx_org_event'):
			case('tx_org_headquarters'):
			case('tx_org_job'):
			case('tx_org_news'):
			case('tx_org_location'):
			case('tx_org_service'):
				// do nothing
				break;
			case('tx_org_downloads'):
				$tcaColumnsMediaFAL = $tcaColumnsMediaFAL + array(
						'documents_display_label' => array(
								'exclude' => 1,
								//'l10n_mode' => 'exclude',
								'label' => 'LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.documents_display_label',
								'config' => array(
										'type' => 'check',
										'items' => array(
												'1' => array(
														'0' => 'LLL:EXT:lang/locallang_core.xml:labels.enabled',
												),
										),
										'default' => '1'
								),
						),
						'documents_display_caption' => array(
								'exclude' => 1,
								//'l10n_mode' => 'exclude',
								'label' => 'LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.documents_display_caption',
								'config' => array(
										'type' => 'check',
										'items' => array(
												'1' => array(
														'0' => 'LLL:EXT:lang/locallang_core.xml:labels.enabled',
												),
										),
										'default' => '0'
								),
						),
						'linkicon_width' => array(
								'exclude' => 1,
								'label' => 'LLL:EXT:org/Resources/Private/Language/tx_org_downloads.xml:tx_org_downloads.linkicon_width',
								'config' => array(
										'type' => 'input',
										'size' => '10',
										'max' => '10',
										'eval' => 'trim',
										'checkbox' => '0',
										'default' => ''
								),
						),
						'linkicon_height' => array(
								'exclude' => 1,
								'label' => 'LLL:EXT:org/Resources/Private/Language/tx_org_downloads.xml:tx_org_downloads.linkicon_height',
								'config' => array(
										'type' => 'input',
										'size' => '10',
										'max' => '10',
										'eval' => 'trim',
										'checkbox' => '0',
										'default' => ''
								),
						),
				);
				break;
		}

		return $tcaColumnsMediaFAL;
	}

	/**
	 * @return      string
	 * @access private
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static private function _ThumbnailFAL()
	{
		return \TYPO3\CMS\Core\Utility\ExtensionManagementUtility::getFileFieldTCAConfig( 'thumbnail', array(
								'appearance' => array(
										'createNewRelationLinkTitle' => 'LLL:EXT:fluid_styled_content/Resources/Private/Language/Database.xlf:tt_content.asset_references.addFileReference'
								)
								, 'foreign_types' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'columns' ][ 'image' ][ 'config' ][ 'foreign_types' ]
										)
										, $GLOBALS[ 'TYPO3_CONF_VARS' ][ 'GFX' ][ 'imagefile_ext' ] . ',doc,docx,ods,odt,sxw,xls,xlsx'
		);
	}

	/**
	 * @access private
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _pathIcon()
	{
		$TYPO3_version = Typo3VersionUtility::Get();

		switch( TRUE )
		{
			case ( $TYPO3_version < 7006000 ):
				return 'selicons/';
			case ( $TYPO3_version >= 7006000 ):
			default:
				return 'EXT:frontend/Resources/Public/Icons/ImageOrientation/';
		}
	}

	/**
	 * @access private
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _pathLL()
	{
		$TYPO3_version = Typo3VersionUtility::Get();

		switch( TRUE )
		{
			case ( $TYPO3_version < 7006000 ):
				return 'org/Resources/Private/Language/6x/cms/locallang_ttc.xlf';
			case ( $TYPO3_version >= 7006000 ):
			default:
				return 'frontend/Resources/Private/Language/locallang_ttc.xlf';
		}
	}

	/**
	 * @param		string $table
	 * @param		string $orderby
	 * @return string
	 * @access private
	 * @version 8.11.0
	 * @since 8.11.0
	 */
	static private function _selectOrderBy( $table, $orderby )
	{
		switch( true )
		{
			case( empty( $orderby ) ):
				return $table . '.title';
			case(!empty( $orderby ) ):
			default:
				return $orderby;
		}
	}

	/**
	 * @param string $MMlocal table_local
	 * @param string $MMforeign table_foreign
	 * @param string $OrderBy Orderby field
	 * @param string $MMopposite Opposite field in case of an opposite relation.
	 * @return array
	 * @access public
	 * @version 8.11.0
	 * @since 8.11.0
	 */
	static private function _selectWhere( $MMlocal, $MMforeign, $OrderBy = NULL, $MMopposite = NULL )
	{
		switch( true )
		{
			case( empty( $MMopposite ) ):
				return ''
								. 'AND ' . $MMforeign . '.' . \Netzmacher\Org\Utility\ExtensionManager\Simplifyer::getPidConfigration() . ' '
								. 'AND ' . $MMforeign . '.deleted = 0 '
								. 'AND ' . $MMforeign . '.hidden = 0 '
								. 'ORDER BY ' . SELF::_selectOrderBy( $MMforeign, $OrderBy )
				;
			case(!empty( $MMopposite ) ):
			default:
				return ''
								. 'AND ' . $MMlocal . '.' . \Netzmacher\Org\Utility\ExtensionManager\Simplifyer::getPidConfigration() . ' '
								. 'AND ' . $MMlocal . '.deleted = 0 '
								. 'AND ' . $MMlocal . '.hidden = 0 '
								. 'ORDER BY ' . SELF::_selectOrderBy( $MMlocal, $OrderBy )
				;
		}
	}

}
