<?php

namespace Netzmacher\Org\TCA;

use Netzmacher\Org\Backend\Extensionmanager;
use Netzmacher\Org\Utility\Typo3VersionUtility;

if( !defined( 'TYPO3_MODE' ) )
{
	die( 'Access denied.' );
}

/* * *************************************************************
 *  Copyright notice
 *
 *  (c) 2017-2020 -  Dirk Wildt <http://wildt.at.die-netzmacher.de>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 * ************************************************************* */

/**
 * @author      Dirk Wildt <http://wildt.at.die-netzmacher.de>
 * @package     TYPO3
 * @subpackage  org
 * @version     8.10.0
 * @since       7.0.2
 */
class Palettes
{

	/**
	 * @access public
	 * @param				array		$palettes: current palettes array
	 * @param				boolean $fal
	 * @return      array		$palettes: extended palettes array
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static public function Icon( $palettes )
	{
		return SELF::_IconFAL( $palettes );
	}

	/**
	 * @access public
	 * @param				array		$palettes: current palettes array
	 * @param				boolean $fal
	 * @return      array		$palettes: extended palettes array
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static public function IconMedium( $palettes )
	{
		return SELF::_IconMediumFAL( $palettes );
	}

	/**
	 * @access public
	 * @param				array	$palettes: current palettes array
	 * @param				boolean $fal
	 * @return      array $palettes: extended palettes array
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static public function Image( $palettes )
	{
		return SELF::_ImageFAL( $palettes );
	}

	/**
	 * @access public
	 * @param				array	$palettes: current palettes array
	 * @param				boolean $fal
	 * @return      array $palettes: extended palettes array
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static public function Media( $palettes )
	{
		return SELF::_MediaFAL( $palettes );
	}

	/**
	 * @return      string
	 * @access public
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static public function RTE()
	{
		$TYPO3_version = Typo3VersionUtility::Get();

		switch( TRUE )
		{
			case ( $TYPO3_version < 8007000 ):
				return ';;;richtext[]:rte_transform[mode=ts]';
			case ( $TYPO3_version >= 8007000 ):
			default:
				return NULL;
		}
	}

	/**
	 * @return      array $palettes: extended palettes array
	 * @access public
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static public function TypePage()
	{
		return array(
				'showitem' => ''
				. 'type,page'
				,
				'canNotCollapse' => 1,
		);
	}

	/**
	 * @return      array $palettes: extended palettes array
	 * @access public
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static public function TypeUrl()
	{
		return array(
				'showitem' => ''
				. 'type,url'
				,
				'canNotCollapse' => 1,
		);
	}

	/**
	 * @access private
	 * @param				array		$palettes: current palettes array
	 * @return      array		$palettes: extended palettes array
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static private function _IconCSV( $palettes )
	{
		$_pathLL = SELF::_pathLL();

		return ( array ) $palettes + array(
				'documentscaption' => array(
						'showitem' => ''
						. 'documentscaption;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.documentscaption'
						,
						'canNotCollapse' => 1,
				),
				'documents_appearance' => array(
						'showitem' => ''
						. 'documentslayout;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.documentslayout,'
						. 'documentssize;LLL:EXT:' . $_pathLL . ':filelink_size_formlabel'
						,
						'canNotCollapse' => 1,
				),
				'documents_upload' => array(
						'showitem' => ''
						. 'documents_from_path;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.documents_from_path,'
						. '--linebreak--,'
						. 'documents;LLL:EXT:' . $_pathLL . ':media.ALT.uploads_formlabel,'
						. 'documentscaption;LLL:EXT:' . $_pathLL . ':imagecaption.ALT.uploads_formlabel;;nowrap,'
						. '--linebreak--,'
						,
						'canNotCollapse' => 1,
				),
				'link' => array(
						'showitem' => ''
						. 'documentslayout;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.documentslayout,'
						. 'documents_display_label,documents_display_caption,documentssize;LLL:EXT:' . $_pathLL . ':filelink_size_formlabel'
						,
						'canNotCollapse' => 1,
				),
				'linkicon_size' => array(
						'showitem' => ''
						. 'linkicon_width;LLL:EXT:org/Resources/Private/Language/tx_org_downloads.xml:tx_org_downloads.linkicon_width,'
						. 'linkicon_height;LLL:EXT:org/Resources/Private/Language/tx_org_downloads.xml:tx_org_downloads.linkicon_height'
						,
						'canNotCollapse' => 1,
				),
				'link_shipping' => array(
						'showitem' => ''
						. 'documentslayout;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.documentslayout,documents_display_label,'
						. 'documents_display_caption'
						,
						'canNotCollapse' => 1,
				),
				'thumbnail_size' => array(
						'showitem' => ''
						. 'thumbnail_width;LLL:EXT:org/Resources/Private/Language/tx_org_downloads.xml:tx_org_downloads.thumbnail_width,'
						. 'thumbnail_height;LLL:EXT:org/Resources/Private/Language/tx_org_downloads.xml:tx_org_downloads.thumbnail_height'
						,
						'canNotCollapse' => 1,
				),
				'type_documents_download' => array(
						'showitem' => ''
						. 'documents;LLL:EXT:org/Resources/Private/Language/tx_org_downloads.xml:tx_org_downloads.file,'
						. 'thumbnail;LLL:EXT:org/Resources/Private/Language/tx_org_downloads.xml:tx_org_downloads.thumbnail_type_documents_download'
						,
						'canNotCollapse' => 1,
				),
				'type_documents_shipping' => array(
						'showitem' => ''
						. 'thumbnail;LLL:EXT:org/Resources/Private/Language/tx_org_downloads.xml:tx_org_downloads.thumbnail_type_documents_shipping'
						,
						'canNotCollapse' => 1,
				),
		);
	}

	/**
	 * @access private
	 * @param				array		$palettes: current palettes array
	 * @return      array		$palettes: extended palettes array
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static private function _IconFAL( $palettes )
	{
		$_pathLL = SELF::_pathLL();

		return ( array ) $palettes + array(
				'documents_appearance' => array(
						'showitem' => ''
						. 'documentslayout;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.documentslayout,'
						. 'documentssize;LLL:EXT:org/Resources/Private/Language/6x/cms/locallang_ttc.xlf:filelink_size_formlabel'
						,
						'canNotCollapse' => 1,
				),
				'documents_upload' => array(
						'showitem' => ''
						. 'documents_from_path;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.documents_from_path,'
						. '--linebreak--,'
						. 'documents,'
						,
						'canNotCollapse' => 1,
				),
				'imagelinks' => array(
						'showitem' => ''
						. 'image_zoom;LLL:EXT:' . $_pathLL . ':image_zoom_formlabel'
						,
						'canNotCollapse' => 1,
				),
				'image_settings' => array(
						'showitem' => ''
						. 'imagewidth;LLL:EXT:' . $_pathLL . ':imagewidth_formlabel,'
						. 'imageheight;LLL:EXT:' . $_pathLL . ':imageheight_formlabel,'
				),
				'link' => array(
						'showitem' => ''
						. 'documentslayout;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.documentslayout,'
						. 'documents_display_label,documents_display_caption,documentssize;LLL:EXT:org/Resources/Private/Language/6x/cms/locallang_ttc.xlf:filelink_size_formlabel'
						,
						'canNotCollapse' => 1,
				),
				'linkicon_size' => array(
						'showitem' => ''
						. 'linkicon_width;LLL:EXT:org/Resources/Private/Language/tx_org_downloads.xml:tx_org_downloads.linkicon_width,'
						. 'linkicon_height;LLL:EXT:org/Resources/Private/Language/tx_org_downloads.xml:tx_org_downloads.linkicon_height'
						,
						'canNotCollapse' => 1,
				),
				'link_shipping' => array(
						'showitem' => ''
						. 'documentslayout;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.documentslayout,documents_display_label,'
						. 'documents_display_caption'
						,
						'canNotCollapse' => 1,
				),
				'thumbnail_size' => array(
						'showitem' => ''
						. 'thumbnail_width;LLL:EXT:org/Resources/Private/Language/tx_org_downloads.xml:tx_org_downloads.thumbnail_width,'
						. 'thumbnail_height;LLL:EXT:org/Resources/Private/Language/tx_org_downloads.xml:tx_org_downloads.thumbnail_height'
						,
						'canNotCollapse' => 1,
				),
				'type_documents_download' => array(
						'showitem' => ''
						. 'documents;LLL:EXT:org/Resources/Private/Language/tx_org_downloads.xml:tx_org_downloads.file,'
						. 'thumbnail;LLL:EXT:org/Resources/Private/Language/tx_org_downloads.xml:tx_org_downloads.thumbnail_type_documents_download'
						,
						'canNotCollapse' => 1,
				),
				'type_documents_shipping' => array(
						'showitem' => ''
						. 'thumbnail;LLL:EXT:org/Resources/Private/Language/tx_org_downloads.xml:tx_org_downloads.thumbnail_type_documents_shipping'
						,
						'canNotCollapse' => 1,
				),
		);
	}

	/**
	 * @access private
	 * @param				array		$palettes: current palettes array
	 * @return      array		$palettes: extended palettes array
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static private function _IconMediumFAL( $palettes )
	{
		$_pathLL = SELF::_pathLL();

		return ( array ) $palettes + array(
				// See: typo3/sysext/frontend/Configuration/TCA/tt_content.php
				'image_settings' => array(
						'showitem' => ''
						. 'imagewidth;LLL:EXT:' . $_pathLL . ':imagewidth_formlabel,'
						. 'imageheight;LLL:EXT:' . $_pathLL . ':imageheight_formlabel,'
				),
		);
	}

	/**
	 * @access private
	 * @param				array	$palettes: current palettes array
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageFAL( $palettes )
	{
		$TYPO3_version = Typo3VersionUtility::Get();

		switch( TRUE )
		{
			case ( $TYPO3_version < 8007000 ):
				return SELF::_ImageFALCss( $palettes );
			case ( $TYPO3_version >= 8007000 ):
			default:
				return SELF::_ImageFALFluid( $palettes );
		}
	}

	/**
	 * @param				array	$palettes: current palettes array
	 * @access private
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageFALCss( $palettes )
	{
		$_pathLL = SELF::_pathLL();

		return ( array ) $palettes + array(
				// See: typo3/sysext/css_styled_content/Configuration/TCA/Overrides/tt_content.php
				'frames' => array(
						'showitem' => '
				layout;LLL:EXT:' . $_pathLL . ':layout_formlabel,
				spaceBefore;LLL:EXT:' . $_pathLL . ':spaceBefore_formlabel,
				spaceAfter;LLL:EXT:' . $_pathLL . ':spaceAfter_formlabel,
				section_frame;LLL:EXT:' . $_pathLL . ':section_frame_formlabel
			',
				),
				// See: typo3/sysext/css_styled_content/Configuration/TCA/Overrides/tt_content.php
				'imageblock' => array(
						'showitem' => '
				imageorient;LLL:EXT:' . $_pathLL . ':imageorient_formlabel,
				imagecols;LLL:EXT:' . $_pathLL . ':imagecols_formlabel,
				--linebreak--,
				image_noRows;LLL:EXT:' . $_pathLL . ':image_noRows_formlabel,
				imagecaption_position;LLL:EXT:' . $_pathLL . ':imagecaption_position_formlabel
			',
				),
				// See: typo3/sysext/frontend/Configuration/TCA/tt_content.php
				'imagelinks' => array(
						'showitem' => '
				image_zoom;LLL:EXT:' . $_pathLL . ':image_zoom_formlabel
			',
				),
				'image_1stforlistonly' => array(
						'showitem' => 'image_1stforlistonly;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.image_1stforlistonly,',
						'canNotCollapse' => 1,
				),
				// See: typo3/sysext/frontend/Configuration/TCA/tt_content.php
				'image_settings' => array(
						'showitem' => '
				imagewidth;LLL:EXT:' . $_pathLL . ':imagewidth_formlabel,
        imageheight;LLL:EXT:' . $_pathLL . ':imageheight_formlabel,
        imageborder;LLL:EXT:' . $_pathLL . ':imageborder_formlabel,
        --linebreak--,
        image_compression;LLL:EXT:' . $_pathLL . ':image_compression_formlabel,
        image_effects;LLL:EXT:' . $_pathLL . ':image_effects_formlabel,
			',
				),
		);
	}

	/**
	 * @param				array	$palettes: current palettes array
	 * @access private
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageFALFluid( $palettes )
	{
		return ( array ) $palettes + array(
				'appearanceLinks' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'palettes' ][ 'appearanceLinks' ],
				'frames' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'palettes' ][ 'frames' ],
				'gallerySettings' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'palettes' ][ 'gallerySettings' ],
				'imagelinks' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'palettes' ][ 'imagelinks' ],
				'image_1stforlistonly' => array(
						'showitem' => 'image_1stforlistonly;LLL:EXT:org/Resources/Private/Language/tx_org.xml:tca_phrase.image_1stforlistonly,',
						'canNotCollapse' => 1,
				),
				'mediaAdjustments' => $GLOBALS[ 'TCA' ][ 'tt_content' ][ 'palettes' ][ 'mediaAdjustments' ],
		);
	}

	/**
	 * @access private
	 * @param				array	$palettes: current palettes array
	 * @return      array	$palettes
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _MediaFAL( $palettes )
	{
		$_pathLL = SELF::_pathLL();

		return ( array ) $palettes + array(
				'documents_appearance' => array(
						'showitem' => ''
						. 'documentslayout;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.documentslayout,'
						. 'documentssize;LLL:EXT:org/Resources/Private/Language/6x/cms/locallang_ttc.xlf:filelink_size_formlabel'
						,
						'canNotCollapse' => 1,
				),
				'documents_upload' => array(
						'showitem' => ''
						. 'documents_from_path;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.documents_from_path,'
						. '--linebreak--,'
						. 'documents,'
						,
						'canNotCollapse' => 1,
				),
				// See: typo3/sysext/fluid_styled_content/Configuration/TCA/Overrides/tt_content.php
//    'gallerySettings' => array (
//      'showitem' => '
//        imageorient;LLL:EXT:' . $_pathLL . ':imageorient_formlabel,
//        imagecols;LLL:EXT:' . $_pathLL . ':imagecols_formlabel
//			'
//    ),
				// See: typo3/sysext/frontend/Configuration/TCA/tt_content.php
				'imagelinks' => array(
						'showitem' => '
				image_zoom;LLL:EXT:' . $_pathLL . ':image_zoom_formlabel
			',
				),
				// See: typo3/sysext/fluid_styled_content/Configuration/TCA/Overrides/tt_content.php
//    'mediaAdjustments' => array (
//      'showitem' => '
//        imagewidth;fluid_styled_content/Resources/Private/Language/Database.xlf:tt_content.palette.textmedia.imagewidth,
//        imageheight;fluid_styled_content/Resources/Private/Language/Database.xlf:tt_content.palette.textmedia.imageheight,
//        imageborder;fluid_styled_content/Resources/Private/Language/Database.xlf:tt_content.palette.textmedia.imageborder
//			'
//    ),
				'link' => array(
						'showitem' => ''
						. 'documentslayout;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.documentslayout,'
						. 'documents_display_label,documents_display_caption,documentssize;LLL:EXT:org/Resources/Private/Language/6x/cms/locallang_ttc.xlf:filelink_size_formlabel'
						,
						'canNotCollapse' => 1,
				),
				'linkicon_size' => array(
						'showitem' => ''
						. 'linkicon_width;LLL:EXT:org/Resources/Private/Language/tx_org_downloads.xml:tx_org_downloads.linkicon_width,'
						. 'linkicon_height;LLL:EXT:org/Resources/Private/Language/tx_org_downloads.xml:tx_org_downloads.linkicon_height'
						,
						'canNotCollapse' => 1,
				),
				'link_shipping' => array(
						'showitem' => ''
						. 'documentslayout;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.documentslayout,documents_display_label,'
						. 'documents_display_caption'
						,
						'canNotCollapse' => 1,
				),
				'thumbnail_size' => array(
						'showitem' => ''
						. 'thumbnail_width;LLL:EXT:org/Resources/Private/Language/tx_org_downloads.xml:tx_org_downloads.thumbnail_width,'
						. 'thumbnail_height;LLL:EXT:org/Resources/Private/Language/tx_org_downloads.xml:tx_org_downloads.thumbnail_height'
						,
						'canNotCollapse' => 1,
				),
				'type_documents_download' => array(
						'showitem' => ''
						. 'documents;LLL:EXT:org/Resources/Private/Language/tx_org_downloads.xml:tx_org_downloads.file,'
						. 'thumbnail;LLL:EXT:org/Resources/Private/Language/tx_org_downloads.xml:tx_org_downloads.thumbnail_type_documents_download'
						,
						'canNotCollapse' => 1,
				),
				'type_documents_shipping' => array(
						'showitem' => ''
						. 'thumbnail;LLL:EXT:org/Resources/Private/Language/tx_org_downloads.xml:tx_org_downloads.thumbnail_type_documents_shipping'
						,
						'canNotCollapse' => 1,
				),
		);
	}

	/**
	 * @access private
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _pathLL()
	{
		$TYPO3_version = Typo3VersionUtility::Get();

		switch( TRUE )
		{
			case ( $TYPO3_version < 7006000 ):
				return 'org/Resources/Private/Language/6x/cms/locallang_ttc.xlf';
			case ( $TYPO3_version >= 7006000 ):
			default:
				return 'frontend/Resources/Private/Language/locallang_ttc.xlf';
		}
	}

}
