<?php

namespace Netzmacher\Org\TCA;

use Netzmacher\Org\Backend\Extensionmanager;
use Netzmacher\Org\Utility\Typo3VersionUtility;

if( !defined( 'TYPO3_MODE' ) )
{
	die( 'Access denied.' );
}

/* * *************************************************************
 *  Copyright notice
 *
 *  (c) 2017-2020 -  Dirk Wildt <http://wildt.at.die-netzmacher.de>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 * ************************************************************* */

/**
 * @author      Dirk Wildt <http://wildt.at.die-netzmacher.de>
 * @package     TYPO3
 * @subpackage  org
 * @version     8.10.0
 * @since       7.0.2
 */
class Types
{

	/**
	 * @access public
	 * @return      string
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static public function Icon()
	{
		return ''
						. '--div--;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.div_icons,'
						. '  icons,icon_offset_x,icon_offset_y,'
		;
	}

	/**
	 * @access public
	 * @param				string $case
	 * @param				boolean $fal
	 * @return      string
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static public function IconMedium( $case = 'big' )
	{
				return SELF::_IconMediumFAL( $case );
	}

	/**
	 * @access public
	 * @param				string	$case: small || medieum || big
	 * @return      string
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static public function Image( $case = 'big' )
	{
				return SELF::_ImageFAL( $case );
	}

	/**
	 * @access public
	 * @param				string	$table
	 * @param				string	$downloadType
	 * @return      string
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static public function Media( $table, $downloadType = 'download' )
	{
				return SELF::_MediaFAL( $table, $downloadType );
	}


	/**
	 * @access private
	 * @param				string	$case: small || medieum || big
	 * @return      string
	 * @version     8.10.0
	 * @since       7.0.2
	 */
	static private function _IconMediumFAL( $case = 'big' )
	{
		switch( $case )
		{
			case('icon'):
			case('small'):
				return ''
								. '--div--;LLL:EXT:org/Resources/Private/Language/tx_org_downloadscat.xml:tx_org_downloadscat.div_color,'
								. '  color,'
								. '  --palette--;LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:palette.image_settings;image_settings,'
				;
			case('image'):
			case('medium'):
			case('big'):
			default:
				// See: typo3/sysext/fluid_styled_content/Configuration/TCA/Overrides/tt_content.php
				return ''
								. '--div--;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:tca_phrase.div_icons,'
								. '  image,'
								. '  --palette--;LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:palette.image_settings;image_settings,'
				;
		}
	}


	/**
	 * @access private
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageFAL( $case = 'big' )
	{
		$TYPO3_version = Typo3VersionUtility::Get();

		switch( TRUE )
		{
			case ( $TYPO3_version < 8007000 ):
				return SELF::_ImageFALCss( $case );
			case ( $TYPO3_version >= 8007000 ):
			default:
				return SELF::_ImageFALFluid( $case );
		}
	}

	/**
	 * @access private
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageFALCss( $case = 'big' )
	{
		switch( $case )
		{
			case('small'):
				return SELF::_ImageFALCssSmall();
			case('medium'):
				return SELF::_ImageFALCssMedium();
			case('big'):
			default:
				return SELF::_ImageFALCssBig();
		}
	}

	/**
	 * @access private
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageFALCssBig()
	{
		$_pathLL = SELF::_pathLL();

		return ''
						. '--div--;LLL:EXT:' . $_pathLL . ':tabs.images,image,'
						. '  --palette--;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:palette.image_1stforlistonly;image_1stforlistonly,'
						. '  --palette--;LLL:EXT:' . $_pathLL . ':palette.imagelinks;imagelinks,'
						. '--div--;LLL:EXT:' . $_pathLL . ':tabs.appearance,'
						. '  --palette--;LLL:EXT:' . $_pathLL . ':palette.frames;frames,'
						. '  --palette--;LLL:EXT:' . $_pathLL . ':palette.image_settings;image_settings,'
						. '  --palette--;LLL:EXT:' . $_pathLL . ':palette.imageblock;imageblock,'
		;
	}

	/**
	 * @access private
	 * @param				string $_pathLL locallang string
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageFALCssMedium()
	{
		$_pathLL = SELF::_pathLL();

		return ''
						. '--div--;LLL:EXT:' . $_pathLL . ':tabs.images,image,'
						. '  --palette--;LLL:EXT:' . $_pathLL . ':palette.image_settings;image_settings,'
		;
	}

	/**
	 * @access private
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageFALCssSmall()
	{
		$_pathLL = SELF::_pathLL();

		return ''
						. '--div--;LLL:EXT:' . $_pathLL . ':tabs.images,image,'
		;
	}

	/**
	 * @access private
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageFALFluid( $case = 'big' )
	{
		switch( $case )
		{
			case('small'):
				return SELF::_ImageFALFluidSmall();
			case('medium'):
				return SELF::_ImageFALFluidMedium();
			case('big'):
			default:
				return SELF::_ImageFALFluidBig();
		}
	}

	/**
	 * @access private
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageFALFluidBig()
	{
		return ''
						. '--div--;LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:tabs.images,image,'
						. '  --palette--;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:palette.image_1stforlistonly;image_1stforlistonly,'
						. '  --palette--;LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:palette.imagelinks;imagelinks,'
						. '--div--;LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:tabs.appearance,'
						. '  --palette--;LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:palette.frames;frames,'
						. '  --palette--;LLL:EXT:frontend/Resources/Private/Language/Database.xlf:tt_content.palette.mediaAdjustments;mediaAdjustments,'
						. '  --palette--;LLL:EXT:frontend/Resources/Private/Language/Database.xlf:tt_content.palette.gallerySettings;gallerySettings,'
						. '  --palette--;LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:palette.appearanceLinks;appearanceLinks,'
		;
	}

	/**
	 * @access private
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageFALFluidMedium()
	{
		$_pathLL = SELF::_pathLL();

		return ''
						. '--div--;LLL:EXT:' . $_pathLL . ':tabs.images,image,'
						. '  --palette--;LLL:EXT:' . $_pathLL . ':palette.image_settings;image_settings,'
		;
	}

	/**
	 * @access private
	 * @param				string $_pathLL locallang string
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _ImageFALFluidSmall()
	{
		$_pathLL = SELF::_pathLL();

		return ''
						. '--div--;LLL:EXT:' . $_pathLL . ':tabs.images,image,'
		;
	}

	/**
	 * @access			private
	 * @param				string	$table
	 * @param				string	$downloadType
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _MediaFAL( $table, $downloadType = 'download' )
	{
		$_pathLL = SELF::_pathLL();

		switch( $table )
		{
			case('tx_org_event'):
			case('tx_org_headquarters'):
			case('tx_org_job'):
			case('tx_org_location'):
			case('tx_org_seminar'):
			case('tx_org_service'):
				$tcaTypesMediaFAL = ''
								. '--div--;LLL:EXT:org/Resources/Private/Language/6x/cms/locallang_ttc.xlf:tabs.media,'
								. '  --palette--;LLL:EXT:org/Resources/Private/Language/6x/cms/locallang_ttc.xlf:media;documents_upload,'
								. '  --palette--;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:palette.appearance;documents_appearance,'
				;
				break;
			case('tx_org_downloads'):
				switch( $downloadType )
				{
					case('shipping'):
						$tcaTypesMediaFAL = ''
										. '--div--;LLL:EXT:' . $_pathLL . ':tabs.media,'
										. '  --palette--;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:palette.type_documents_shipping;type_documents_shipping,'
										. '  --palette--;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:palette.link;link,'
										. '  --palette--;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:palette.thumbnail_size;thumbnail_size,'
//                  . '  --palette--;LLL:EXT:fluid_styled_content/Resources/Private/Language/Database.xlf:tt_content.palette.gallerySettings;gallerySettings,'
//                  . '  --palette--;LLL:EXT:' . $_pathLL . ':palette.appearanceLinks;appearanceLinks,'
						;
						break;
					case('download'):
					case('download_shipping'):
					default:
						$tcaTypesMediaFAL = ''
										. '--div--;LLL:EXT:' . $_pathLL . ':tabs.media,'
										. '  --palette--;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:palette.type_documents_download;type_documents_download,'
//            . '  --palette--;LLL:EXT:' . $_pathLL . ':palette.imagelinks;imagelinks,'
										. '  --palette--;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:palette.link;link,'
										. '  --palette--;LLL:EXT:org/Resources/Private/Language/locallang_db.xml:palette.thumbnail_size;thumbnail_size,'
//                  . '  --palette--;LLL:EXT:fluid_styled_content/Resources/Private/Language/Database.xlf:tt_content.palette.gallerySettings;gallerySettings,'
//                  . '  --palette--;LLL:EXT:' . $_pathLL . ':palette.appearanceLinks;appearanceLinks,'
						;
						break;
				}
				break;
		}

		return $tcaTypesMediaFAL;
	}

	/**
	 * @access private
	 * @return      string
	 * @version     8.10.0
	 * @since       8.10.0
	 */
	static private function _pathLL()
	{
		$TYPO3_version = Typo3VersionUtility::Get();

		switch( TRUE )
		{
			case ( $TYPO3_version < 7006000 ):
				return 'org/Resources/Private/Language/6x/cms/locallang_ttc.xlf';
			case ( $TYPO3_version >= 7006000 ):
			default:
				return 'frontend/Resources/Private/Language/locallang_ttc.xlf';
		}
	}

}
