# Organiser version: 8.16.3. Date: 19-01-29

# BEFOREHAND
#   * Before executing any SQL statement, please make a copy of your Organiser tables
#   * If you manage news in more than one folder, you have to repeat the SQL statements for each folder.
#   * You must adapt the @srcePid and the @destPid in the whole document to your needs
#   * You don't need to empty any table:
#			* All records will migrated with a new uid
#			* The tx_org_mm_all table takes care about the new uids
#
# RESTRICTIONS
#		Migration scripts from below doesn't take care for
#		* tt_news_related_mm

# FIRST
# The best is, to remove all Organiser records supported by the TYPO3 backend, if you like to start with empty Organiser tables. 
# This should remove linked files too.
# Don't forget to remove deleted files by the backend recycler for ever!

# BACKUP TABLES
CREATE TABLE tx_org_news_1806241053 LIKE tx_org_news;
INSERT INTO tx_org_news_1806241053 SELECT * FROM tx_org_news;
CREATE TABLE tx_org_newscat_1806241053 LIKE tx_org_newscat;
INSERT INTO tx_org_newscat_1806241053 SELECT * FROM tx_org_newscat;
CREATE TABLE tx_org_mm_all_1806241053 LIKE tx_org_mm_all;
INSERT INTO tx_org_mm_all_1806241053 SELECT * FROM tx_org_mm_all;

# NOT RECOMMENED
# But if you like to empty the Organiser tables by MySQL statements, please take the next five lines.
-- TRUNCATE tx_org_news;
-- TRUNCATE tx_org_newscat;


# MAPPING
# Source         @srcePid    Destination     @destPid
# ----------------------- -- ------------------------
# tt_news		     1118	       tx_org_news	       1535
# tt_news_cat		 7	         tx_org_newscat      301


# BEGIN of the statements

# Empty all tables with the given page uid
DELETE FROM tx_org_newscat WHERE pid = '301';
DELETE FROM tx_org_news WHERE pid IN (1535, 8001, 8002, 8003, 8004, 8005, 8006, 8007, 8008, 8009);
SET @srcePid = '7'; -- <- tt_news_cat
DELETE FROM tx_org_mm_all WHERE (table_local LIKE 'tx_org_news' AND table_foreign LIKE 'tx_org_newscat') AND import_srcePid = @srcePid;


-- SET @destPidList = '1535, 8001, 8002, 8003, 8004, 8005, 8006, 8007, 8008, 8009';  -- tx_org_news

# Migration: tt_news_cat -> to tx_org_newscat
-- Next four lines: if parent categories aren't used:
SET @srcePid = '7';  -- tt_news_cat
SET @destPid = '301';  -- tx_org_newscat
INSERT INTO tx_org_newscat (pid, uid_parent, tstamp, crdate, hidden, deleted, title, title_lang_ol, image, import_srcePid, import_srceTable, import_srceUid)
SELECT @destPid, parent_category, tstamp, crdate, hidden, deleted, title, title_lang_ol, image, @srcePid, 'tt_newscat', uid  FROM tt_news_cat WHERE tt_news_cat.pid = @srcePid;
-- Next four lines: if parent categories are used. Runs only in an empty table tx_org_newscat!
SET @srcePid = '7';  -- tt_news_cat
SET @destPid = '301';  -- tx_org_newscat
INSERT INTO tx_org_newscat (uid, pid, uid_parent, tstamp, crdate, hidden, deleted, title, title_lang_ol, image, import_srcePid, import_srceTable, import_srceUid)
SELECT uid, @destPid, parent_category, tstamp, crdate, hidden, deleted, title, title_lang_ol, image, @srcePid, 'tt_newscat', uid  FROM tt_news_cat WHERE tt_news_cat.pid = @srcePid;


# Migration: tt_news -> to tx_org_news
# See: /home/dwildt/Schreibtisch/debitoren/K-O/N/netzbegruenung.de/relaunch/helfer/kv_ansbach_sql_tx_cal.ods
SET @srcePid = '1118';  -- tt_news
SET @destPid = '1535';  -- tx_org_news
INSERT INTO tx_org_news (archivedate, bodytext, crdate, cruser_id, datetime, deleted, documents,  endtime, fe_group, hidden, image, imagecaption, imageseo,       l10n_diffsource, l10n_parent, page, pid,  seo_keywords, starttime, subtitle, sys_language_uid, title, tstamp, tx_org_newscat, type, url,     import_srcePid, import_srceTable, import_srceUid )
SELECT                   archivedate, bodytext, crdate, cruser_id, datetime, deleted, news_files, endtime, fe_group, hidden, image, imagecaption, imagetitletext, l18n_diffsource, l18n_parent, page, @destPid, keywords, starttime, short,    sys_language_uid, title, tstamp, category,       type, ext_url, @srcePid,       'tt_newscat',     uid            FROM tt_news WHERE tt_news.pid = @srcePid;
# Update the type
SET @destPid = '1535';  -- tx_org_news
-- Next three lines, if tx_org_news weren't empty before migration
UPDATE tx_org_news SET type = 'url'    WHERE type = '2' AND tx_org_news.pid IN (1535, 8001, 8002, 8003, 8004, 8005, 8006, 8007, 8008, 8009);
UPDATE tx_org_news SET type = 'page'   WHERE type = '1' AND tx_org_news.pid IN (1535, 8001, 8002, 8003, 8004, 8005, 8006, 8007, 8008, 8009);
UPDATE tx_org_news SET type = 'record' WHERE type = '0' AND tx_org_news.pid IN (1535, 8001, 8002, 8003, 8004, 8005, 8006, 8007, 8008, 8009);
-- Next three lines, if tx_org_news were empty before migration
UPDATE tx_org_news SET type = 'url'    WHERE type = '2';
UPDATE tx_org_news SET type = 'page'   WHERE type = '1';
UPDATE tx_org_news SET type = 'record' WHERE type = '0';


# Migration: tx_org_mm_all
-- 0. step: OBLIGATE! You can delete all records with the given srcePid from tx_org_mm_all
SET @srcePid = '7'; -- <- tt_news_cat
DELETE FROM tx_org_mm_all WHERE (table_local LIKE 'tx_org_news' AND table_foreign LIKE 'tx_org_newscat') AND import_srcePid = @srcePid;
-- 1. step: migration with former uids
SET @srcePid = '7'; -- <- tt_news_cat
INSERT INTO tx_org_mm_all (uid_local, uid_foreign, sorting, table_local, table_foreign, import_srceTable, import_srcePid)
SELECT uid_local, uid_foreign, sorting, 'tx_org_news', 'tx_org_newscat', 'tt_news_cat_mm', @srcePid 
FROM tt_news_cat_mm WHERE uid_local IN(SELECT uid  FROM tt_news WHERE tt_news.pid IN (7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 104, 110));
-- 2. step: update uid_local and uid_foreign
SET @srcePid = '7'; -- <- tt_news_cat
UPDATE tx_org_mm_all, tx_org_newscat SET tx_org_mm_all.uid_foreign = tx_org_newscat.uid
WHERE tx_org_mm_all.uid_foreign = tx_org_newscat.import_srceUid 
AND tx_org_mm_all.table_foreign = 'tx_org_newscat' 
AND tx_org_mm_all.import_srcePid = @srcePid;
UPDATE tx_org_mm_all, tx_org_news SET tx_org_mm_all.uid_local = tx_org_news.uid
WHERE tx_org_mm_all.uid_local = tx_org_news.import_srceUid 
AND tx_org_mm_all.table_local = 'tx_org_news' 
AND tx_org_mm_all.import_srcePid = @srcePid;
# Migration: tx_org_mm_all: end


-- # Migrate data from third party extension (here: newscomfort)
UPDATE tx_org_news, tt_news
SET    tx_org_news.teaser_title    = tt_news.tx_newscomfort_title,
       tx_org_news.teaser_subtitle = tt_news.tx_newscomfort_subheader,
       tx_org_news.teaser_short    = tt_news.tx_newscomfort_short
WHERE  tx_org_news.uid = tt_news.uid;


# Get list of images and files for CSV export, copy it to
SELECT image FROM tt_news_cat WHERE image != '' AND tt_news_cat.pid = 7;

SELECT image FROM tt_news WHERE image != '' AND tt_news.pid IN (7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 104, 110);

SELECT news_files FROM tt_news WHERE news_files != '' AND tt_news.pid IN (7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 104, 110);

-- Run the FAL update script of this extension org!


--   # Set default image properties for all news
-- If tx_org_news weren't empty before migration
SET @destPid = '1535';
UPDATE  tx_org_news
SET     tx_org_news.imageorient  = 25,
        tx_org_news.imagewidth   = 293,
        tx_org_news.image_zoom   = 1,
			  tx_org_news.imagecols    = 1
WHERE   tx_org_news.pid IN (1535, 8001, 8002, 8003, 8004, 8005, 8006, 8007, 8008, 8009);
-- If tx_org_news were empty before migration
UPDATE  tx_org_news
SET     tx_org_news.imageorient  = 25,
        tx_org_news.imagewidth   = 293,
        tx_org_news.image_zoom   = 1,
			  tx_org_news.imagecols    = 1

-- 
-- 
-- # TYPO3 6.x link syntax
--   # Move links from tt_news to tx_org_news, which are generated by the linkhandler
--   # Test with the record with the uid 14651
-- SET     @destPid = '1535';
-- UPDATE  tx_org_news
-- SET     bodytext = REPLACE(bodytext, "record:tt_news:", "record:tx_org_news:")
-- WHERE   tx_org_news.pid = @destPid
-- AND     tx_org_news.uid = 14651;
--   # All record tx_org_news records with the pid @destPid
SET     @destPid = '1535';
UPDATE  tx_org_news
SET     bodytext = REPLACE(bodytext, "record:tt_news:", "record:tx_org_news:")
WHERE   tx_org_news.pid IN (1535, 8001, 8002, 8003, 8004, 8005, 8006, 8007, 8008, 8009);