# Organiser version: 8.16.0. Date: 19-01-19
#   cal 1.11.1

# BEFOREHAND
#   * Before executing any SQL statement, please make a copy of your Organiser tables
#   * You must adapt the @srcePid and the @destPid in the whole document to your needs
#   * You don't need to empty any table:
#			* All records will migrated with a new uid
#			* The tx_org_mm_all table takes care about the new uids
#
# RESTRICTIONS
#		Migration scripts from below doesn't take care for
#		* images
#		* files
#		* recurring events
#		* messages in case of changings

# FIRST
# The best is, to remove all Organiser records supported by the TYPO3 backend, if you like to start with empty Organiser tables. 
# This should remove linked files too.
# Don't forget to remove deleted files by the backend recycler for ever!

# BACKUP TABLES
-- CREATE TABLE tx_org_calcal_1802041026 LIKE tx_org_calcal;
-- INSERT INTO tx_org_calcal_1802041026 SELECT * FROM tx_org_calcal;
-- CREATE TABLE tx_org_caltype_1802041026 LIKE tx_org_caltype;
-- INSERT INTO tx_org_caltype_1802041026 SELECT * FROM tx_org_caltype;
-- CREATE TABLE tx_org_cal_1802041026 LIKE tx_org_cal;
-- INSERT INTO tx_org_cal_1802041026 SELECT * FROM tx_org_cal;
-- CREATE TABLE tx_org_location_1802041026 LIKE tx_org_location;
-- INSERT INTO tx_org_location_1802041026 SELECT * FROM tx_org_location;
-- CREATE TABLE tx_org_headquarters_1802041026 LIKE tx_org_headquarters;
-- INSERT INTO tx_org_headquarters_1802041026 SELECT * FROM tx_org_headquarters;
-- CREATE TABLE tx_org_mm_all_1802041026 LIKE tx_org_mm_all;
-- INSERT INTO tx_org_mm_all_1802041026 SELECT * FROM tx_org_mm_all;

# NOT RECOMMENED
# But if you like to empty the Organiser tables by MySQL statements, please take the next five lines.
-- TRUNCATE tx_org_calcal;
-- TRUNCATE tx_org_caltype;
-- TRUNCATE tx_org_cal;
-- TRUNCATE tx_org_location;
-- TRUNCATE tx_org_headquarters;


# MAPPING
# Source           @srcePid    Destination          @destPid
# ------------------------- -- -----------------------------
# tx_cal_calendar		     21    tx_org_calcal				    1810
# tx_cal_category		     21    tx_org_caltype				    1810
# tx_cal_event				   21    tx_org_cal						    1810
# tx_cal_location		     21    tx_org_location			    1812
# tx_cal_organizer		   21    tx_org_headquarters	    1814

# pid list of tx_cal_calendar and tx_org_cal...
# ----------------------------------------------------------------------------------------
# @srcePidList	21, 1300, 1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311, 1312
# @destPidList	1810, 2462, 2475, 2476, 2477, 2478, 2479, 2480, 2481, 2482, 2483, 2484, 2485, 2486


# BEGIN of the statements

# Empty all tables with the given page uid
DELETE FROM tx_org_calcal WHERE pid = '1810';
DELETE FROM tx_org_caltype WHERE pid = '1810';
DELETE FROM tx_org_cal WHERE pid IN (1810, 2462, 2475, 2476, 2477, 2478, 2479, 2480, 2481, 2482, 2483, 2484, 2485, 2486);
DELETE FROM tx_org_location WHERE pid = '1812';
DELETE FROM tx_org_headquarters WHERE pid = '1814';
DELETE FROM tx_org_mm_all WHERE (table_local LIKE 'tx_org_calcal' OR table_foreign LIKE 'tx_org_calcal') AND import_srcePid IN (21, 1300, 1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311, 1312);
DELETE FROM tx_org_mm_all WHERE (table_local LIKE 'tx_org_caltype' OR table_foreign LIKE 'tx_org_caltype') AND import_srcePid IN (21, 1300, 1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311, 1312);
DELETE FROM tx_org_mm_all WHERE (table_local LIKE 'tx_org_cal' OR table_foreign LIKE 'tx_org_cal') AND import_srcePid IN (21, 1300, 1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311, 1312);
DELETE FROM tx_org_mm_all WHERE (table_local LIKE 'tx_org_location' OR table_foreign LIKE 'tx_org_location') AND import_srcePid IN (21, 1300, 1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311, 1312);
DELETE FROM tx_org_mm_all WHERE (table_local LIKE 'tx_org_headquarters' OR table_foreign LIKE 'tx_org_headquarters') AND import_srcePid IN (21, 1300, 1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311, 1312);

# Migration: tx_cal_calendar -> tx_org_calcal
SET @destPid = '1810'; -- <- tx_org_calcal
-- calendar type: default (database), no external calendar, no ics file! 
INSERT INTO tx_org_calcal (pid, tstamp, cruser_id, crdate, hidden, deleted, title, import_srcePid, import_srceTable, import_srceUid)
SELECT @destPid, tstamp, cruser_id, crdate, hidden, deleted, title, pid, 'tx_cal_calendar', uid FROM tx_cal_calendar WHERE tx_cal_calendar.pid IN (21, 1300, 1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311, 1312);

# Migration: tx_cal_category -> tx_org_caltype
SET @destPid = '1810'; -- <- tx_org_caltype
INSERT INTO tx_org_caltype (pid, uid_parent, tstamp, cruser_id, crdate, hidden, deleted, title, import_srcePid, import_srceTable, import_srceUid)
SELECT @destPid, parent_category, tstamp, cruser_id, crdate, hidden, deleted, title, pid, 'tx_cal_category', uid FROM tx_cal_category WHERE tx_cal_category.pid IN (21, 1300, 1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311, 1312);

# Migration: tx_cal_event -> tx_org_cal
# See: statements.ods
-- SET @srcePid = '21'; -- <- tx_cal_event
-- SET @destPid = '1810'; -- <- tx_org_cal
-- -- Doesn't import repeating events
-- INSERT INTO tx_org_cal (type, pid, crdate, cruser_id, deleted, bodytext, endtime, url, fe_cruser_id, hidden, image, imagecaption, imageseo, import_srcePid, import_srceTable, import_srceUid, l10n_parent, location, locationurl, organiser, organiserurl, page, starttime, sys_language_uid, teaser_title, title, tstamp, datetimeend, datetime)
-- SELECT 'record', @destPid, crdate, cruser_id, deleted, description, endtime, ext_url, fe_cruser_id, hidden, image, imagecaption, imagetitletext, @srcePid, 'tx_cal_event', uid, l18n_parent, location, location_link, organizer, organizer_link, page, starttime, sys_language_uid, teaser, title, tstamp, UNIX_TIMESTAMP(STR_TO_DATE(end_date, '%Y%m%d')) + end_time , UNIX_TIMESTAMP(STR_TO_DATE(start_date, '%Y%m%d')) + start_time FROM tx_cal_event WHERE tx_cal_event.pid = @srcePid;

# Migration: Update type of tx_org_cal
UPDATE tx_org_cal SET type = 'notype' WHERE type = '4' AND tx_org_cal.pid IN (1810, 2462, 2475, 2476, 2477, 2478, 2479, 2480, 2481, 2482, 2483, 2484, 2485, 2486);
UPDATE tx_org_cal SET type = 'notype' WHERE type = '3' AND tx_org_cal.pid IN (1810, 2462, 2475, 2476, 2477, 2478, 2479, 2480, 2481, 2482, 2483, 2484, 2485, 2486);
UPDATE tx_org_cal SET type = 'url'    WHERE type = '2' AND tx_org_cal.pid IN (1810, 2462, 2475, 2476, 2477, 2478, 2479, 2480, 2481, 2482, 2483, 2484, 2485, 2486);
UPDATE tx_org_cal SET type = 'page'   WHERE type = '1' AND tx_org_cal.pid IN (1810, 2462, 2475, 2476, 2477, 2478, 2479, 2480, 2481, 2482, 2483, 2484, 2485, 2486);
UPDATE tx_org_cal SET type = 'record' WHERE type = '0' AND tx_org_cal.pid IN (1810, 2462, 2475, 2476, 2477, 2478, 2479, 2480, 2481, 2482, 2483, 2484, 2485, 2486);

# Migration: tx_cal_location -> tx_org_location
SET @destPid = '1812'; -- <- tx_org_location
-- Doesn't import images!
INSERT INTO tx_org_location (pid, tstamp, cruser_id, crdate, hidden, deleted, title, bodytext, mail_street, mail_postcode, mail_city, mail_country, telephone, email, fax, url, mail_lat, mail_lon, import_srcePid, import_srceTable, import_srceUid )
SELECT @destPid, tstamp, cruser_id, crdate, hidden, deleted, name, description, street, zip, city, country, phone, email, fax, link, latitude, longitude, pid, 'tx_cal_location', uid FROM tx_cal_location WHERE tx_cal_location.pid IN (21, 1300, 1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311, 1312);

# Migration: tx_cal_organizer -> tx_org_headquarters
SET @destPid = '1814'; -- <- tx_org_headquarters
-- Doesn't respect images, files, recurring events, messages in case og changings
INSERT INTO tx_org_headquarters (pid, tstamp, cruser_id, crdate, hidden, deleted, fe_cruser_id, title, bodytext, mail_street, mail_postcode, mail_city, mail_country, telephone, email, fax, url, import_srcePid, import_srceTable, import_srceUid )
SELECT @destPid, tstamp, cruser_id, crdate, hidden, deleted, fe_user_id, name, description, street, zip, city, country, phone, email, fax, link, pid, 'tx_cal_organizer', uid FROM tx_cal_organizer WHERE tx_cal_organizer.pid IN (21, 1300, 1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311, 1312);

# Migration: tx_org_mm_all
-- 0. step: OBLIGATE! You can delete all records with the given srcePid from tx_org_mm_all
DELETE FROM tx_org_mm_all WHERE (table_local LIKE 'tx_org_calcal' OR table_foreign LIKE 'tx_org_calcal') AND import_srcePid IN (21, 1300, 1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311, 1312);
DELETE FROM tx_org_mm_all WHERE (table_local LIKE 'tx_org_caltype' OR table_foreign LIKE 'tx_org_caltype') AND import_srcePid IN (21, 1300, 1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311, 1312);
DELETE FROM tx_org_mm_all WHERE (table_local LIKE 'tx_org_cal' OR table_foreign LIKE 'tx_org_cal') AND import_srcePid IN (21, 1300, 1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311, 1312);
DELETE FROM tx_org_mm_all WHERE (table_local LIKE 'tx_org_location' OR table_foreign LIKE 'tx_org_location') AND import_srcePid IN (21, 1300, 1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311, 1312);
DELETE FROM tx_org_mm_all WHERE (table_local LIKE 'tx_org_headquarters' OR table_foreign LIKE 'tx_org_headquarters') AND import_srcePid IN (21, 1300, 1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311, 1312);
-- 1. step: migration with former uids
INSERT INTO tx_org_mm_all (	uid_local, uid_foreign, table_local, table_foreign,	import_srceTable, import_srcePid, import_srceUid)
SELECT uid,	calendar_id, 'tx_org_cal', 'tx_org_calcal', 'tx_cal_event', pid, uid FROM tx_cal_event WHERE tx_cal_event.pid IN (21, 1300, 1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311, 1312) AND calendar_id > 0;
INSERT INTO tx_org_mm_all ( uid_local, uid_foreign, sorting, table_local, table_foreign,  import_srceTable)
SELECT uid_local, uid_foreign, sorting, 'tx_org_cal', 'tx_org_caltype', 'tx_cal_event_category_mm' FROM tx_cal_event_category_mm WHERE uid_local IN(SELECT uid  FROM tx_cal_event WHERE tx_cal_event.pid IN (21, 1300, 1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311, 1312));
INSERT INTO tx_org_mm_all (	uid_local, uid_foreign, table_local, table_foreign,	import_srceTable, import_srcePid, import_srceUid)
SELECT uid,	location_id, 'tx_org_cal', 'tx_org_location', 'tx_cal_event', pid, uid FROM tx_cal_event WHERE tx_cal_event.pid IN (21, 1300, 1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311, 1312) AND location_id > 0;
INSERT INTO tx_org_mm_all (	uid_local, uid_foreign, table_local, table_foreign,	import_srceTable, import_srcePid, import_srceUid)
SELECT organizer_id, uid,	'tx_org_headquarters', 'tx_org_cal', 'tx_cal_event', pid, uid FROM tx_cal_event WHERE tx_cal_event.pid IN (21, 1300, 1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311, 1312) AND organizer_id > 0;

-- 2. step: update uid_local and uid_foreign
UPDATE tx_org_mm_all, tx_org_cal SET tx_org_mm_all.uid_local = tx_org_cal.uid
WHERE tx_org_mm_all.uid_local = tx_org_cal.import_srceUid 
AND tx_org_mm_all.table_local = 'tx_org_cal';
UPDATE tx_org_mm_all, tx_org_cal SET tx_org_mm_all.uid_foreign = tx_org_cal.uid
WHERE tx_org_mm_all.uid_foreign = tx_org_cal.import_srceUid 
AND tx_org_mm_all.table_foreign = 'tx_org_cal';
UPDATE tx_org_mm_all, tx_org_calcal SET tx_org_mm_all.uid_foreign = tx_org_calcal.uid
WHERE tx_org_mm_all.uid_foreign = tx_org_calcal.import_srceUid 
AND tx_org_mm_all.table_foreign = 'tx_org_calcal';
UPDATE tx_org_mm_all, tx_org_caltype SET tx_org_mm_all.uid_foreign = tx_org_caltype.uid
WHERE tx_org_mm_all.uid_foreign = tx_org_caltype.import_srceUid 
AND tx_org_mm_all.table_foreign = 'tx_org_caltype';
UPDATE tx_org_mm_all, tx_org_location SET tx_org_mm_all.uid_foreign = tx_org_location.uid
WHERE tx_org_mm_all.uid_foreign = tx_org_location.import_srceUid 
AND tx_org_mm_all.table_foreign = 'tx_org_location';
UPDATE tx_org_mm_all, tx_org_headquarters SET tx_org_mm_all.uid_local = tx_org_headquarters.uid
WHERE tx_org_mm_all.uid_local = tx_org_headquarters.import_srceUid 
AND tx_org_mm_all.table_local = 'tx_org_headquarters';
# Migration: tx_org_mm_all: end