# Organiser version: 8.16.0. Date: 19-01-18

# BEFOREHAND
#   * Before executing any SQL statement, please make a copy of your Organiser tables
#   * If you manage news in more than one folder, you have to repeat the SQL statements for each folder.
#   * You must adapt the @srcePid and the @destPid in the whole document to your needs
#   * You don't need to empty any table:
#			* All records will migrated with a new uid
#			* The sys_category_record_mm table takes care about the new uids
#
# RESTRICTIONS
#		Migration scripts from below doesn't take care for
#		* content_elements
#		* tx_news_domain_model_news_tag_mm

# FIRST
# The best is, to remove all Organiser records supported by the TYPO3 backend, if you like to start with empty Organiser tables. 
# This should remove linked files too.
# Don't forget to remove deleted files by the backend recycler for ever!

# BACKUP TABLES
CREATE TABLE tx_org_news_1901182207 LIKE tx_org_news;
INSERT INTO tx_org_news_1901182207 SELECT * FROM tx_org_news;
CREATE TABLE tx_org_newscat_1901182207 LIKE tx_org_newscat;
INSERT INTO tx_org_newscat_1901182207 SELECT * FROM tx_org_newscat;
CREATE TABLE tx_org_mm_all_1901182207 LIKE sys_category_record_mm;
INSERT INTO tx_org_mm_all_1901182207 SELECT * FROM sys_category_record_mm;

# NOT RECOMMENED
# But if you like to empty the Organiser tables by MySQL statements, please take the next five lines.
-- TRUNCATE tx_org_news;


# MAPPING
# Source                           @srcePid Destination     @destPid
# -------------------------------- -------- --------------- --------
# tx_news_domain_model_news		     741	    tx_org_news	        2455


# BEGIN of the statements

# Empty all tables with all tx_org_news records (dangerous!)
TRUNCATE tx_org_news;
DELETE FROM sys_category_record_mm WHERE ( tablenames LIKE 'tx_org_news' AND fieldname LIKE 'sys_category');
DELETE FROM sys_file_reference WHERE tablenames LIKE 'tx_org_news' AND (fieldname LIKE 'documents' OR fieldname LIKE 'image');

# Empty all tables with the given page uids
SET @srcePid = '741';  --  tx_news_domain_model_news
SET @destPid = '2455';  -- tx_org_news
DELETE FROM tx_org_news WHERE pid = @destPid;
DELETE FROM sys_category_record_mm WHERE ( tablenames LIKE 'tx_org_news' AND fieldname LIKE 'sys_category') AND tx_org_importSrcePid = @srcePid;
DELETE FROM sys_file_reference WHERE tablenames LIKE 'tx_org_news' AND (fieldname LIKE 'documents' OR fieldname LIKE 'image') AND tx_org_importSrcePid = @srcePid;

# Migration:  tx_news_domain_model_news -> to tx_org_news
SET @srcePid = '741';  --  tx_news_domain_model_news
SET @destPid = '2455';  -- tx_org_news
INSERT INTO tx_org_news (archivedate, bodytext, crdate, cruser_id, datetime, deleted, documents,		 endtime, fe_group, hidden, image,     imagecols, l10n_parent, page,				 pid,			 seo_description, seo_keywords, starttime, sys_language_uid, teaser_short, title, topnews,   tstamp, tx_org_newscat, type, url,				 import_srcePid, import_srceTable, import_srceUid )
SELECT                   archive,			bodytext, crdate, cruser_id, datetime, deleted, related_files, endtime, fe_group, hidden, fal_media, '1',       l10n_parent, internalurl, @destPid, description,			keywords,			starttime, sys_language_uid, teaser,	     title, istopnews, tstamp, categories,     type, externalurl, @srcePid,       ' tx_news_domain_model_news',        uid            FROM  tx_news_domain_model_news WHERE  tx_news_domain_model_news.pid = @srcePid;
-- Update the type
SET @destPid = '2455';  -- tx_org_news
UPDATE tx_org_news SET type = 'url'    WHERE type = '2' AND tx_org_news.pid IN (@destPid);
UPDATE tx_org_news SET type = 'page'   WHERE type = '1' AND tx_org_news.pid IN (@destPid);
UPDATE tx_org_news SET type = 'record' WHERE type = '0' AND tx_org_news.pid IN (@destPid);

# Migration: sys_category_record_mm
-- 0. step: OBLIGATE! You can delete all records with the given srcePid from sys_category_record_mm
-- SET @srcePid = '741'; -- <- tx_news_domain_model_news
-- DELETE FROM sys_category_record_mm WHERE ( tablenames LIKE 'tx_org_news' AND fieldname LIKE 'sys_category') AND tx_org_importSrcePid = @srcePid;
-- 1. step: migration with former uids
SET @srcePid = '741'; -- <- tx_news_domain_model_news
INSERT INTO sys_category_record_mm (uid_local, uid_foreign, sorting, tablenames, fieldname, tx_org_importSrceTable, tx_org_importSrcePid, tx_org_importSrceUid)
SELECT uid_local, uid_foreign, sorting, 'tx_org_news', 'sys_category', 'tx_news_domain_model_news', @srcePid, uid_foreign
FROM sys_category_record_mm WHERE tablenames = 'tx_news_domain_model_news' AND fieldname = 'categories' AND uid_foreign IN(SELECT uid  FROM  tx_news_domain_model_news WHERE  tx_news_domain_model_news.pid IN (@srcePid));

-- 2. step: update uid_local and uid_foreign
SET @srcePid = '741'; -- <- tx_news_domain_model_news
UPDATE sys_category_record_mm, tx_org_news SET uid_foreign = uid
WHERE sys_category_record_mm.tx_org_importSrceUid = tx_org_news.import_srceUid 
AND sys_category_record_mm.tablenames = 'tx_org_news' 
AND sys_category_record_mm.fieldname = 'sys_category' 
AND sys_category_record_mm.tx_org_importSrcePid = @srcePid;
# Migration: sys_category_record_mm: end


# Migration: sys_file_reference
-- 0. step: OBLIGATE! You can delete all records with the given srcePid from sys_file_reference
-- SET @destPid = '2455';  -- tx_org_news
-- SET @srcePid = '741'; -- <- tx_news_domain_model_news
-- DELETE FROM sys_file_reference WHERE tablenames LIKE 'tx_org_news' AND (fieldname LIKE 'documents' OR fieldname LIKE 'image') AND tx_org_importSrcePid = @srcePid;
-- 1. step: migration with former uids
SET @srcePid = '741'; -- <- tx_news_domain_model_news
INSERT INTO sys_file_reference (pid, uid_local, uid_foreign, sorting, table_local, tablenames, fieldname, title, description, alternative, tx_org_importSrceTable, tx_org_importSrcePid, tx_org_importSrceUid)
SELECT @destPid, uid_local, uid_foreign, sorting, table_local, 'tx_org_news', 'image', title, description, alternative, 'tx_news_domain_model_news', @srcePid, uid_foreign
FROM sys_file_reference WHERE tablenames = 'tx_news_domain_model_news' AND fieldname = 'fal_media' AND uid_foreign IN(SELECT uid  FROM  tx_news_domain_model_news WHERE  tx_news_domain_model_news.pid IN (@srcePid));
SET @srcePid = '741'; -- <- tx_news_domain_model_news
INSERT INTO sys_file_reference (pid, uid_local, uid_foreign, sorting, table_local, tablenames, fieldname, title, description, alternative, tx_org_importSrceTable, tx_org_importSrcePid, tx_org_importSrceUid)
SELECT @destPid, uid_local, uid_foreign, sorting, table_local, 'tx_org_news', 'documents', title, description, alternative, 'tx_news_domain_model_news', @srcePid, uid_foreign
FROM sys_file_reference WHERE tablenames = 'tx_news_domain_model_news' AND fieldname = 'fal_related_files' AND uid_foreign IN(SELECT uid  FROM  tx_news_domain_model_news WHERE  tx_news_domain_model_news.pid IN (@srcePid));

-- 2. step: update uid_foreign
SET @srcePid = '741'; -- <- tx_news_domain_model_news
UPDATE sys_file_reference, tx_org_news SET sys_file_reference.uid_foreign = tx_org_news.uid
WHERE sys_file_reference.tx_org_importSrceUid = tx_org_news.import_srceUid 
AND sys_file_reference.tablenames = 'tx_org_news' 
AND (sys_file_reference.fieldname = 'documents' OR sys_file_reference.fieldname = 'image')
AND sys_file_reference.tx_org_importSrcePid = @srcePid;
# Migration: sys_file_reference: end

--   # Set default image properties for all news
SET @destPid = '2455';  -- tx_org_news
UPDATE  tx_org_news
SET     tx_org_news.imageorient  = 25,
        tx_org_news.imagewidth   = 293,
        tx_org_news.image_zoom   = 1,
			  tx_org_news.imagecols    = 1
WHERE   tx_org_news.pid IN (@destPid);