# Organiser version: 8.14.3. Date: 18-06-24

# Convert tx_org_news to tx_org_cal, where tx_org_news has a defined category

# BEFOREHAND
#   * Before executing any SQL statement, please make a copy of your Organiser tables
#   * If you manage news in more than one folder, you have to repeat the SQL statements for each folder.
#   * You must adapt the @srcePid and the @destPid in the whole document to your needs
#   * You don't need to empty any table:
#   * All records will migrated with a new uid
#   * The tx_org_mm_all table takes care about the new uids

# FIRST
# The best is, to remove all Organiser records supported by the TYPO3 backend, if you like to start with empty Organiser tables. 
# This should remove linked files too.
# Don't forget to remove deleted files by the backend recycler for ever!

# BACKUP TABLES
CREATE TABLE tx_org_cal_1806241842 LIKE tx_org_cal;
INSERT INTO tx_org_cal_1806241842 SELECT * FROM tx_org_cal;
CREATE TABLE tx_org_caltype_1806241842 LIKE tx_org_caltype;
INSERT INTO tx_org_caltype_1806241842 SELECT * FROM tx_org_caltype;
CREATE TABLE tx_org_news_1806241842 LIKE tx_org_news;
INSERT INTO tx_org_news_1806241842 SELECT * FROM tx_org_news;
CREATE TABLE tx_org_mm_all_1806241842 LIKE tx_org_mm_all;
INSERT INTO tx_org_mm_all_1806241842 SELECT * FROM tx_org_mm_all;

# MAPPING folders
# Source         @srcePid    Destination     @destPid
# ----------------------- -- ------------------------
# tx_org_news    1532        tx_org_cal      1533
# tx_org_newscat 1532        tx_org_caltype  1533

# Empty all tables with the given page uid
DELETE FROM tx_org_caltype WHERE pid = '1533';
DELETE FROM tx_org_cal WHERE pid IN (1533);
SET @srcePid = '1533'; -- <- tx_org_cal
DELETE FROM tx_org_mm_all WHERE (table_local LIKE 'tx_org_cal' AND table_foreign LIKE 'tx_org_caltype') AND import_srcePid = @srcePid;

# Migration: tx_org_newscat -> to tx_org_caltype. ATTENTION: without icons, without uid_parent!
SET @srcePid = '1532';  -- tx_org_newscat
SET @destPid = '1533';  -- tx_org_caltype
SET @srceCat = '2';     -- category: event
INSERT INTO tx_org_caltype (pid,      tstamp, crdate, cruser_id, deleted, hidden, title, title_lang_ol, tx_org_cal,	 import_srcePid, import_srceTable, import_srceUid)
SELECT                      @destPid, tstamp, crdate, cruser_id, deleted, hidden, title, title_lang_ol, tx_org_news, @srcePid,       'tx_org_newscat',     uid
FROM tx_org_newscat 
WHERE tx_org_newscat.pid = @srcePid
  AND tx_org_newscat.uid = @srceCat;

# MAPPING category
# Source         @srceCat    Destination     @destCat
# ----------------------- -- ------------------------
# tx_org_newscat 2           tx_org_caltype  7

# Migration: tx_org_news -> to tx_org_cal. ATTENTION: without icons, without uid_parent!
SET @srcePid = '1532';  -- tx_org_news
SET @destPid = '1533';  -- tx_org_cal
SET @srceCat = '2';     -- category: event
SET @destCat = '7';     -- category: event
INSERT INTO tx_org_cal (
	pid, 
	tstamp, crdate, cruser_id, sys_language_uid, l10n_parent, l10n_state,
	bodytext, datetime, deleted, 
  documents, documents_from_path, documentscaption, documentslayout, documentssize,
	embeddedcode,
	endtime,
	fe_cruser_id, fe_group, 
	frame_class,
	hidden,
	image, image_1stforlistonly, image_compression, image_effects, image_frames, image_link, image_noRows, image_zoom, imageborder, imagecaption, imagecaption_position, imagecols, imageheight, imageorient, imageseo, imagewidth,
	layout,
	marginal_short, marginal_subtitle, marginal_title,
	newsletter,
	page, pages,
	section_frame,
	seo_description, seo_keywords,
	space_after_class, space_before_class, spaceAfter, spaceBefore,
	starttime,
	subtitle,
	teaser_short, teaser_short_for_singleview, teaser_subtitle, teaser_title,
	title,
	topitem, tx_org_caltype,
	type, url,
	import_srcePid, import_srceTable, import_srceUid
)
SELECT
	@destPid, 
	tstamp, crdate, cruser_id, sys_language_uid, l10n_parent, l10n_state,
	bodytext, datetime, deleted, 
  documents, documents_from_path, documentscaption, documentslayout, documentssize,
	embeddedcode,
	endtime,
	fe_cruser_id, fe_group, 
	frame_class,
	hidden,
	image, image_1stforlistonly, image_compression, image_effects, image_frames, image_link, image_noRows, image_zoom, imageborder, imagecaption, imagecaption_position, imagecols, imageheight, imageorient, imageseo, imagewidth,
	layout,
	marginal_short, marginal_subtitle, marginal_title,
	newsletter,
	page, pages,
	section_frame,
	seo_description, seo_keywords,
	space_after_class, space_before_class, spaceAfter, spaceBefore,
	starttime,
	subtitle,
	teaser_short, teaser_short_for_singleview, teaser_subtitle, teaser_title,
	title,
	topnews, tx_org_newscat,
	type, url,
	@srcePid, 'tx_org_news', uid
FROM tx_org_news
JOIN  tx_org_mm_all 
ON (  tx_org_news.uid = tx_org_mm_all.uid_local
  AND tx_org_mm_all.table_local = 'tx_org_news'
  AND tx_org_mm_all.table_foreign = 'tx_org_newscat'
  AND tx_org_mm_all.uid_foreign = @srceCat
)
WHERE tx_org_news.pid = @srcePid;

# Migration: tx_org_mm_all
-- 0. step: OBLIGATE! You can delete all records with the given srcePid from tx_org_mm_all
SET @srcePid = '1532';  -- tx_org_news
DELETE FROM tx_org_mm_all WHERE (table_local LIKE 'tx_org_cal' AND table_foreign LIKE 'tx_org_caltype') AND import_srcePid = @srcePid;
-- 1. step: migration with former uids
SET @srcePid = '1532';  -- tx_org_news
SET @srceCat = '2';     -- category: event
INSERT INTO tx_org_mm_all (uid_local, uid_foreign, sorting, table_local,  table_foreign,    import_srceTable, import_srcePid)
SELECT                     uid_local, uid_foreign, sorting, 'tx_org_cal', 'tx_org_caltype', 'tx_org_mm_all',  @srcePid 
FROM   tx_org_mm_all 
WHERE  tx_org_mm_all.table_local = 'tx_org_news'
  AND  tx_org_mm_all.table_foreign = 'tx_org_newscat'
  AND  tx_org_mm_all.uid_foreign = @srceCat;
-- 2. step: update uid_local and uid_foreign
SET @srcePid = '1532';  -- tx_org_news
SET @destPid = '1533';  -- tx_org_cal
SET @srceCat = '2';     -- category: event
SET @destCat = '7';     -- category: event
UPDATE tx_org_mm_all SET tx_org_mm_all.uid_foreign = @destCat
WHERE tx_org_mm_all.uid_foreign = @srceCat
AND tx_org_mm_all.table_local = 'tx_org_cal' 
AND tx_org_mm_all.table_foreign = 'tx_org_caltype' 
AND tx_org_mm_all.import_srceTable = 'tx_org_mm_all'
AND tx_org_mm_all.import_srcePid = @srcePid;
UPDATE tx_org_mm_all, tx_org_cal SET tx_org_mm_all.uid_local = tx_org_cal.uid
WHERE tx_org_mm_all.uid_local = tx_org_cal.import_srceUid
AND tx_org_mm_all.table_local = 'tx_org_cal' 
AND tx_org_mm_all.table_foreign = 'tx_org_caltype' 
AND tx_org_mm_all.import_srceTable = 'tx_org_mm_all'
AND tx_org_mm_all.import_srcePid = @srcePid;
# Migration: tx_org_mm_all: end

# FAL
# Check, if there are records with images
SET @srcePid = '1532';  -- tx_org_news
SET @srceCat = '2';     -- category: event
SELECT uid, image FROM tx_org_news
JOIN  tx_org_mm_all 
ON (  tx_org_news.uid = tx_org_mm_all.uid_local
  AND tx_org_mm_all.table_local = 'tx_org_news'
  AND tx_org_mm_all.table_foreign = 'tx_org_newscat'
  AND tx_org_mm_all.uid_foreign = @srceCat
)
WHERE image > 0
  AND tx_org_news.pid = @srcePid;

# DELETE deprecated tx_org_news with category event
SET @srcePid = '1532';  -- tx_org_news
SET @srceCat = '2';     -- category: event
-- SELECT tx_org_news.uid, tx_org_news.title FROM tx_org_news
DELETE tx_org_news, tx_org_mm_all FROM tx_org_news
INNER JOIN  tx_org_mm_all 
ON (  tx_org_news.uid = tx_org_mm_all.uid_local
  AND tx_org_mm_all.table_local = 'tx_org_news'
  AND tx_org_mm_all.table_foreign = 'tx_org_newscat'
  AND tx_org_mm_all.uid_foreign = @srceCat
)
WHERE tx_org_news.pid = @srcePid;